@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -176,7 +176,7 @@ avi_frame_get_bitmap_real (AviFrame   *avi_frame,
           }
       bmih = g_malloc (bm_all_bytes (avi_frame->bmih));
       g_memmove (bmih, avi_frame->bmih, avi_frame->bmih_size);
-      output = (guint8 *)bmih + bm_header_bytes (bmih);
+      output = bm_image_pointer (bmih);
       while (j <= i)
         {
           if (avi_edit->file->index[j].size > 0)
@@ -330,14 +330,14 @@ avi_frame_get_bitmap (AviFrame   *avi_frame,
         width,幅
        height,高さ
           RET,RAWへのポインタ,NULL:エラー                               */
-guint8 *
-avi_frame_get_raw (AviFrame  *avi_frame,
+guchar *
+avi_frame_get_raw (AviFrame   *avi_frame,
                    const gint  pos,
                    const gint  width,
                    const gint  height)
 {
-  gint i, n, xx, yy;
-  guchar *p;
+  gint i, n, yy;
+  guchar *p, *raw;
   guint8 *q;
   AviEdit *avi_edit;
   BitmapInfoHeader *bmih;
@@ -369,26 +369,33 @@ avi_frame_get_raw (AviFrame  *avi_frame,
   bmih = avi_frame_get_bitmap (avi_frame, pos, width, height, 32);
   if (!bmih)
     return NULL;
-  p = g_malloc (width * height * 4 * sizeof (guchar));
-  q = (guchar *)bmih + bm_header_bytes (bmih);
+  p = raw = g_malloc (width * height * 4 * sizeof (guchar));
+  q = (guint8 *)bmih + bm_all_bytes (bmih) - bm_line_bytes (bmih);
   for (yy = 0; yy < height; yy++)
-    for (xx = 0; xx < width; xx++)
-      {
-        gint src, dst;
+    {
+      guint8 *r;
+      gint xx;
 
-        src = xx * 4 + (height - yy - 1) * width * 4;
-        dst = xx * 4 + yy * width * 4;
-        p[dst]  = q[src + 2];
-        p[dst + 1] = q[src + 1];
-        p[dst + 2] = q[src];
-        p[dst + 3] = q[src + 3];
-      }
+      r = q;
+      for (xx = 0; xx < width; xx++)
+        {
+          guchar green, blue;
+
+          blue = *r++;
+          green = *r++;
+          *p++ = *r++;
+          *p++ = green;
+          *p++ = blue;
+          *p++ = *r++;
+        }
+      q -= bm_line_bytes (bmih);
+    }
   g_free (avi_edit->buf[0].data);
-  avi_edit->buf[0].data = p;
+  avi_edit->buf[0].data = raw;
   avi_edit->buf[0].raw = TRUE;
   avi_edit->buf[0].width = width;
   avi_edit->buf[0].height = height;
-  return p;
+  return raw;
 }
 
 
