@@ -1,10 +1,10 @@
 /*
     avicore
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "avibase.h"
 #include "avifmt.h"
@@ -157,15 +156,26 @@ avi_main_streams (const gchar *file)
         }
       case AVI_FILE_GSR:
         {
-          FileIO *fio;
-          GsrMainHeader gmh;
+          gint streams = 0;
 
           /* ja:ファイルを開く */
-          return file && (fio = fileio_open (file, FILEIO_ACCESS_READ,
-                                FILEIO_SHARE_READ, FILEIO_MODE_OPEN_EXISTING))
-                    && ((fileio_read (fio, &gmh, GMH_SIZE) == GMH_SIZE)
-                                                        & fileio_close (fio))
-                                                ? gmh_get_streams (&gmh) : 0;
+          if (file)
+            {
+              FileIO *fio;
+
+              fio = fileio_open (file, FILEIO_ACCESS_READ,
+                                FILEIO_SHARE_READ, FILEIO_MODE_OPEN_EXISTING);
+              if (fio)
+                {
+                  gboolean result;
+                  GsrMainHeader gmh;
+
+                  result = fileio_read (fio, &gmh, GMH_SIZE) == GMH_SIZE;
+                  if (fileio_close (fio) && result)
+                    streams = gmh_get_streams (&gmh);
+                }
+            }
+          return streams;
         }
       case AVI_FILE_BITMAP:
       case AVI_FILE_PIXBUF:
@@ -216,16 +226,20 @@ avi_edit_open_with_param (const gchar *file,
         }
       else
         {
+          gboolean result = FALSE;
           IcmObject *icm_object;
 
           /* ja:圧縮 */
           icm_object = icm_open (avi_edit->file->handler, ICM_MODE_DECOMPRESS);
-          if (!icm_object
-                || !(avi_edit->bmih = g_malloc (icm_decompress_get_format_size
-                                        (icm_object, avi_edit->file->bmih)))
-                || (!icm_decompress_get_format (icm_object,
-                                        avi_edit->file->bmih, avi_edit->bmih)
-                                                    | !icm_close (icm_object)))
+          if (icm_object)
+            {
+              avi_edit->bmih = g_malloc (icm_decompress_get_format_size
+                                        (icm_object, avi_edit->file->bmih));
+              result = icm_decompress_get_format (icm_object,
+                                        avi_edit->file->bmih, avi_edit->bmih);
+              result = icm_close (icm_object) && result;
+            }
+          if (!result)
             {
               avi_file_close (avi_edit->file);
               g_free (avi_edit->bmih);
@@ -245,16 +259,20 @@ avi_edit_open_with_param (const gchar *file,
         }
       else
         {
+          gboolean result = FALSE;
           AcmObject *acm_object;
 
           /* ja:圧縮 */
           acm_object = acm_open (wfx_get_format_tag (avi_edit->file->wfx));
-          if (!acm_object
-                || !(avi_edit->wfx = g_malloc (acm_decompress_get_format_size
-                                            (acm_object, avi_edit->file->wfx)))
-                || (!acm_decompress_get_format (acm_object,
-                                            avi_edit->file->wfx, avi_edit->wfx)
-                                                    | !acm_close (acm_object)))
+          if (acm_object)
+            {
+              avi_edit->wfx = g_malloc (acm_decompress_get_format_size
+                                            (acm_object, avi_edit->file->wfx));
+              result = acm_decompress_get_format (acm_object,
+                                        avi_edit->file->wfx, avi_edit->wfx);
+              result = acm_close (acm_object) && result;
+            }
+          if (!result)
             {
               avi_file_close (avi_edit->file);
               g_free (avi_edit->wfx);
@@ -377,17 +395,21 @@ avi_edit_open_from_memory (gconstpointer data)
             }
           else
             {
+              gboolean result = FALSE;
               AcmObject *acm_object;
 
               /* ja:圧縮 */
               acm_object = acm_open (wfx_get_format_tag (avi_edit->file->wfx));
-              if (!acm_object
-                    || !(avi_edit->wfx = g_malloc
+              if (acm_object)
+                {
+                  avi_edit->wfx = g_malloc
                                 (acm_decompress_get_format_size (acm_object,
-                                                        avi_edit->file->wfx)))
-                    || (!acm_decompress_get_format (acm_object,
-                                            avi_edit->file->wfx, avi_edit->wfx)
-                                                    | !acm_close (acm_object)))
+                                                        avi_edit->file->wfx));
+                  result = acm_decompress_get_format (acm_object,
+                                        avi_edit->file->wfx, avi_edit->wfx);
+                  result = acm_close (acm_object) && result;
+                }
+              if (!result)
                 {
                   avi_file_close (avi_edit->file);
                   g_free (avi_edit->wfx);
