@@ -1,10 +1,10 @@
 /*
     avicore
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "avibase.h"
 
@@ -64,12 +63,14 @@ avi_pcm_open (AviEdit *avi_edit)
 gboolean
 avi_pcm_close (AviPcm *avi_pcm)
 {
-  gboolean result;
+  gboolean result = TRUE;
 
   if (!avi_pcm)
     return FALSE;
-  result = (!avi_pcm->wcv || wave_convert_end (avi_pcm->wcv, NULL, NULL))
-         & (!avi_pcm->acm_object || acm_close (avi_pcm->acm_object));
+  if (avi_pcm->wcv && !wave_convert_end (avi_pcm->wcv, NULL, NULL))
+    result = FALSE;
+  if (avi_pcm->acm_object && !acm_close (avi_pcm->acm_object))
+    result = FALSE;
   g_free (avi_pcm->wfx);
   g_free (avi_pcm->tmp_buf);
   g_free (avi_pcm);
@@ -194,13 +195,14 @@ avi_pcm_get_raw (AviPcm      *avi_pcm,
               avi_pcm->marker = -1;
               if (avi_pcm->acm_object)
                 {
+                  gboolean result;
                   gpointer e_buf = NULL;
                   gsize e_samples;
 
-                  if ((!acm_decompress_end (avi_pcm->acm_object,
-                                                            &e_buf, &e_samples)
-                                            | !acm_close (avi_pcm->acm_object))
-                        || !wave_convert (avi_pcm->wcv,
+                  result = acm_decompress_end (avi_pcm->acm_object,
+                                                        &e_buf, &e_samples);
+                  if (!acm_close (avi_pcm->acm_object) || !result
+                             || !wave_convert (avi_pcm->wcv,
                                 e_buf, e_samples, &conv_buf, &conv_samples))
                     {
                       g_free (e_buf);
@@ -285,12 +287,13 @@ avi_pcm_get_raw (AviPcm      *avi_pcm,
 
           if (avi_pcm->acm_object)
             {
+              gboolean result;
               gpointer e_buf = NULL;
               gsize e_samples;
 
-              if ((!acm_decompress_end (avi_pcm->acm_object,
-                                                            &e_buf, &e_samples)
-                                            | !acm_close (avi_pcm->acm_object))
+              result = acm_decompress_end (avi_pcm->acm_object,
+                                                        &e_buf, &e_samples);
+              if (!acm_close (avi_pcm->acm_object) || !result
                     || !wave_convert (avi_pcm->wcv,
                                 e_buf, e_samples, &conv_buf, &conv_samples))
                 {
