@@ -1,10 +1,10 @@
 /*
     avicore
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "avibase.h"
 #include "avifmt.h"
@@ -607,6 +606,8 @@ avi_edit_from_scenario (const gchar *scenario)
     {
       for (i = 0; i < count; i++)
         {
+          gboolean result = FALSE;
+
           /* ja:サンプル数 */
           if (avi_edit[i]->file)
             {
@@ -637,6 +638,7 @@ avi_edit_from_scenario (const gchar *scenario)
                   if (bmih_get_size_image (avi_edit[i]->bmih) <= 0)
                     bmih_set_size_image (avi_edit[i]->bmih,
                                         bm_image_bytes (avi_edit[i]->bmih));
+                  result = TRUE;
                 }
               else
                 {
@@ -650,23 +652,13 @@ avi_edit_from_scenario (const gchar *scenario)
                       avi_edit[i]->bmih = g_malloc
                                 (icm_decompress_get_format_size (icm_object,
                                                     avi_edit[i]->file->bmih));
-                      if (icm_decompress_get_format (icm_object,
-                                    avi_edit[i]->file->bmih, avi_edit[i]->bmih)
-                                                    & icm_close (icm_object))
-                        {
-                          avi_edit[i]->bmih = g_realloc (avi_edit[i]->bmih,
+                      result = icm_decompress_get_format (icm_object,
+                                avi_edit[i]->file->bmih, avi_edit[i]->bmih);
+                      if (icm_close (icm_object) && result)
+                        avi_edit[i]->bmih = g_realloc (avi_edit[i]->bmih,
                                         bm_header_bytes (avi_edit[i]->bmih));
-                        }
                       else
-                        {
-                          avi_edit_close (avi_edit[i]);
-                          avi_edit[i] = NULL;
-                        }
-                    }
-                  else
-                    {
-                      avi_edit_close (avi_edit[i]);
-                      avi_edit[i] = NULL;
+                        result = FALSE;
                     }
                 }
             }
@@ -677,6 +669,7 @@ avi_edit_from_scenario (const gchar *scenario)
                 {
                   avi_edit[i]->wfx = g_memdup (avi_edit[i]->file->wfx,
                                     wf_header_bytes (avi_edit[i]->file->wfx));
+                  result = TRUE;
                 }
               else
                 {
@@ -685,25 +678,32 @@ avi_edit_from_scenario (const gchar *scenario)
                   /* ja:圧縮 */
                   acm_object = acm_open
                                 (wfx_get_format_tag (avi_edit[i]->file->wfx));
-                  if (acm_object && (avi_edit[i]->wfx
+                  if (acm_object)
+                    {
+                      avi_edit[i]->wfx
                                     = g_malloc (acm_decompress_get_format_size
-                                        (acm_object, avi_edit[i]->file->wfx)))
-                        && (acm_decompress_get_format (acm_object,
-                                    avi_edit[i]->file->wfx, avi_edit[i]->wfx)
-                                                    & acm_close (acm_object)))
-                    {
-                      avi_edit[i]->rate
+                                        (acm_object, avi_edit[i]->file->wfx));
+                      result = acm_decompress_get_format (acm_object,
+                                    avi_edit[i]->file->wfx, avi_edit[i]->wfx);
+                      if (acm_close (acm_object) && result)
+                        {
+                          avi_edit[i]->rate
                             = wfx_get_average_bytes_per_sec (avi_edit[i]->wfx);
-                      avi_edit[i]->scale
+                          avi_edit[i]->scale
                             = wfx_get_block_align (avi_edit[i]->wfx);
-                    }
-                  else
-                    {
-                      avi_edit_close (avi_edit[i]);
-                      avi_edit[i] = NULL;
+                        }
+                      else
+                        {
+                          result = FALSE;
+                        }
                     }
                 }
             }
+          if (!result)
+            {
+              avi_edit_close (avi_edit[i]);
+              avi_edit[i] = NULL;
+            }
 #ifdef XXX
           g_print("type=%X,rate=%u,scale=%u,length=%d\n",avi_edit[i]->type,avi_edit[i]->rate,avi_edit[i]->scale,avi_edit[i]->length);
           for (avi_file=avi_edit[i]->file;avi_file!=NULL;
