@@ -1,10 +1,10 @@
 /*
     Video maid
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,15 +13,16 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "command.h"
 #include "file.h"
 #include "general.h"
+#include "menu.h"
 #include "sigfile.h"
 #include "size.h"
 #include "thread.h"
+#include "misc/misc.h"
 #include "orz/orzmdi.h"
 
 
@@ -498,6 +499,7 @@ history_operation (VmaidWindow    *vmaid,
     }
   e.cursor = vmaid->cursor;
   e.select = vmaid->select;
+  e.next = NULL;
   for (i = 0; i < 2; i++)
     e.avi_edit[i] = vmaid->avi_edit[i];
   vmaid->cursor = d->cursor;
