@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1545,6 +1545,361 @@ const gchar *size24_xpm[] = {
 "                                                "};
 
 
+/* XPM */
+const gchar *codec16_xpm[] = {
+"16 16 87 1",
+"   c None",
+".  c #000000",
+"+  c #FEFEFE",
+"@  c #DADADA",
+"#  c #CBCBCB",
+"$  c #FDFDFD",
+"%  c #E0E0E0",
+"&  c #C1C1C1",
+"*  c #F1F1F1",
+"=  c #CAC8C1",
+"-  c #BBBBBB",
+";  c #C3C3C3",
+">  c #FBFBFB",
+",  c #A8A8A8",
+"'  c #B1B1B1",
+")  c #EBEBE8",
+"!  c #EBEBEB",
+"~  c #ADADAD",
+"{  c #767676",
+"]  c #5D5D5D",
+"^  c #D8D8D8",
+"/  c #F9F8F8",
+"(  c #CCCCCC",
+"_  c #E2E2E2",
+":  c #858585",
+"<  c #3D3D3C",
+"[  c #D2D0CC",
+"}  c #F7F7F7",
+"|  c #DEDBD6",
+"1  c #A9A9A9",
+"2  c #EFEFEF",
+"3  c #848484",
+"4  c #737373",
+"5  c #D3D2CF",
+"6  c #E3E2E1",
+"7  c #DFDEDC",
+"8  c #DBDAD7",
+"9  c #A4A19C",
+"0  c #656565",
+"a  c #292929",
+"b  c #838383",
+"c  c #C4C4C4",
+"d  c #F3F3F3",
+"e  c #1D1D1D",
+"f  c #D2D1D0",
+"g  c #50504F",
+"h  c #EDEDED",
+"i  c #ECECEC",
+"j  c #111111",
+"k  c #3D3D3D",
+"l  c #494746",
+"m  c #DEDEDE",
+"n  c #BFBFBF",
+"o  c #363636",
+"p  c #C8C7C6",
+"q  c #6C6967",
+"r  c #708295",
+"s  c #CFD6DD",
+"t  c #7C91A7",
+"u  c #E8E8E8",
+"v  c #D6D5D5",
+"w  c #8A8784",
+"x  c #7D8C9C",
+"y  c #788DA4",
+"z  c #7F99B3",
+"A  c #1F272F",
+"B  c #E6E6E6",
+"C  c #ECEBEA",
+"D  c #72706D",
+"E  c #8D99A5",
+"F  c #748AA2",
+"G  c #849EB9",
+"H  c #4D5F73",
+"I  c #E5E5E5",
+"J  c #E4E4E4",
+"K  c #D5D4D3",
+"L  c #6B6A69",
+"M  c #7D91A7",
+"N  c #849EBA",
+"O  c #D9D9D9",
+"P  c #E3E3E3",
+"Q  c #DCDCDC",
+"R  c #525252",
+"S  c #66798F",
+"T  c #ACACAC",
+"U  c #BCBCBC",
+"V  c #A0A0A0",
+"  .........     ",
+" .++@.#+$%&.  . ",
+" .+*.=.-*;>,..'.",
+" .+**.).!~{].^. ",
+" ..**./.(_:<..  ",
+" .[..}|.123.4.  ",
+" ..56789.0abc.  ",
+" .d.e..fg.0!;.  ",
+" .$hiiijkl.mn.  ",
+" .$!...o.pq.'.  ",
+" .$.rst.u.vw..  ",
+" ..xsyzAB(.CD.  ",
+" .EsFGH.IIJ.KL. ",
+" .sMNH.OJPPQ.fR ",
+" .MSH.TU----V.. ",
+" ............   "};
+
+
+/* XPM */
+const gchar *codec24_xpm[] = {
+"24 24 218 2",
+"   c None",
+".  c #000000",
+"+  c #BAB5AB",
+"@  c #D0CDC6",
+"#  c #88857D",
+"$  c #D2D2D2",
+"%  c #ECECEC",
+"&  c #DFDFDF",
+"*  c #C9C6BE",
+"=  c #CCC8C1",
+"-  c #F8F8F8",
+";  c #FEFEFE",
+">  c #F9F9F9",
+",  c #DADADA",
+"'  c #585858",
+")  c #F4F4F4",
+"!  c #E9E9E9",
+"~  c #D1D1D1",
+"{  c #E5E3E0",
+"]  c #D5D5D5",
+"^  c #FDFDFD",
+"/  c #FFFFFF",
+"(  c #C7C7C7",
+"_  c #D6D6D6",
+":  c #757575",
+"<  c #7B7B7B",
+"[  c #F2F2F2",
+"}  c #E1E1E1",
+"|  c #2E2E2E",
+"1  c #F6F5F5",
+"2  c #929292",
+"3  c #C0C0C0",
+"4  c #EFEFEF",
+"5  c #CCCCCC",
+"6  c #AFAFAF",
+"7  c #D3D1CB",
+"8  c #909090",
+"9  c #C1C0BF",
+"0  c #F0EFED",
+"a  c #9B9A96",
+"b  c #5A5A5A",
+"c  c #F3F3F2",
+"d  c #FAFAFA",
+"e  c #AFAFAE",
+"f  c #DCDCDC",
+"g  c #A5A19C",
+"h  c #EAE9E5",
+"i  c #F3F1F0",
+"j  c #ECECEB",
+"k  c #F7F7F6",
+"l  c #A4A4A3",
+"m  c #EDEDED",
+"n  c #202020",
+"o  c #A19D96",
+"p  c #C1BDB4",
+"q  c #DBD8D3",
+"r  c #D9D6D1",
+"s  c #89857E",
+"t  c #F0EFEE",
+"u  c #9C9C9C",
+"v  c #EBEBEB",
+"w  c #AAAAAA",
+"x  c #636363",
+"y  c #121212",
+"z  c #EAE9E6",
+"A  c #F5F4F3",
+"B  c #C6C2BA",
+"C  c #939391",
+"D  c #848383",
+"E  c #646363",
+"F  c #5F5C54",
+"G  c #EAEAEA",
+"H  c #D7D7D6",
+"I  c #CCCCCB",
+"J  c #C7C7C6",
+"K  c #C7C6C5",
+"L  c #C2C1C1",
+"M  c #F4F4F3",
+"N  c #CBC7C0",
+"O  c #AEADAC",
+"P  c #B5B5B3",
+"Q  c #BBBAB8",
+"R  c #A9A8A6",
+"S  c #86827A",
+"T  c #EDEDEC",
+"U  c #E8E7E6",
+"V  c #E4E3E2",
+"W  c #E2E2E0",
+"X  c #DAD9D8",
+"Y  c #A6A5A4",
+"Z  c #D3D2D0",
+"`  c #CFCECD",
+" . c #C3C2C1",
+".. c #8F8A81",
+"+. c #F3F3F1",
+"@. c #F2F1F0",
+"#. c #E9E9E7",
+"$. c #D9D9D7",
+"%. c #C3C3C2",
+"&. c #676560",
+"*. c #54524D",
+"=. c #C0BFBD",
+"-. c #E1E0DD",
+";. c #D2D1CE",
+">. c #8D887E",
+",. c #F4F3F2",
+"'. c #F3F2F1",
+"). c #F1F1EF",
+"!. c #777676",
+"~. c #797978",
+"{. c #85827E",
+"]. c #79756F",
+"^. c #AFAEAC",
+"/. c #DFDDDA",
+"(. c #979288",
+"_. c #7590AE",
+":. c #A4BAD0",
+"<. c #90A6BE",
+"[. c #908F8E",
+"}. c #9F9F9E",
+"|. c #BEBDBC",
+"1. c #B8B4AD",
+"2. c #87837C",
+"3. c #9C9A98",
+"4. c #A29C91",
+"5. c #EFEFED",
+"6. c #D3DFEA",
+"7. c #A2AEBC",
+"8. c #9DB6CE",
+"9. c #637B95",
+"0. c #AAA9A7",
+"a. c #A5A4A3",
+"b. c #E2E2E2",
+"c. c #EEEEED",
+"d. c #636059",
+"e. c #849CB6",
+"f. c #D7E2ED",
+"g. c #8D98A5",
+"h. c #9DB8D2",
+"i. c #607791",
+"j. c #B7B6B4",
+"k. c #C3C2C0",
+"l. c #B9B9B6",
+"m. c #99ADC3",
+"n. c #DFE7F0",
+"o. c #8193A9",
+"p. c #586D84",
+"q. c #5B7189",
+"r. c #D0CECB",
+"s. c #CCCBC8",
+"t. c #BAB9B5",
+"u. c #F1F1F1",
+"v. c #EEEDEB",
+"w. c #A7A6A5",
+"x. c #726F6A",
+"y. c #A1B4C8",
+"z. c #EEF3F6",
+"A. c #60768F",
+"B. c #B1B0AD",
+"C. c #C1C1BD",
+"D. c #D6D5D1",
+"E. c #DAD9D5",
+"F. c #CACAC6",
+"G. c #B5B5B1",
+"H. c #DEDDDC",
+"I. c #787776",
+"J. c #4E4E4D",
+"K. c #91A6BE",
+"L. c #F0F4F7",
+"M. c #97A5B6",
+"N. c #898886",
+"O. c #BAB9B6",
+"P. c #CECDC9",
+"Q. c #DBDAD6",
+"R. c #DFDEDA",
+"S. c #D7D6D3",
+"T. c #C8C6C2",
+"U. c #B4B2AF",
+"V. c #BFBEBD",
+"W. c #AAAAA9",
+"X. c #ACACAB",
+"Y. c #B0C6DB",
+"Z. c #EDF2F6",
+"`. c #818A95",
+" + c #6B6A68",
+".+ c #B6B5B2",
+"++ c #C8C7C3",
+"@+ c #D9D8D4",
+"#+ c #DEDDD9",
+"$+ c #E0DEDA",
+"%+ c #DCDAD6",
+"&+ c #D5D4D0",
+"*+ c #C4C2BF",
+"=+ c #B1AFAB",
+"-+ c #6C85A1",
+";+ c #C0D1E2",
+">+ c #545352",
+",+ c #B2B1AE",
+"'+ c #C5C3C0",
+")+ c #D3D2CE",
+"!+ c #DEDCD8",
+"~+ c #DBD9D5",
+"{+ c #D2D0CC",
+"]+ c #C3C2BE",
+"^+ c #B2B1AC",
+"/+ c #7D7870",
+"(+ c #3D3B36",
+"_+ c #827D74",
+":+ c #8C887D",
+"<+ c #999388",
+"[+ c #9F9A8E",
+"}+ c #A29C90",
+"|+ c #A19B8F",
+"1+ c #A19B90",
+"2+ c #9F998D",
+"3+ c #9C968B",
+"4+ c #928D82",
+"5+ c #5F5C52",
+"            . .                                 ",
+"      . . . + @ # . . . . . . .                 ",
+"    . $ % & . * = + . - ; > , ' .     . .       ",
+"    . ) - ! ~ . { * . ] ^ / ( ~ _ . . / : .     ",
+"    . . < [ } | 1 * . 2 > ^ 3 } 4 . / 5 6 .     ",
+"    . 7 8 . . 9 0 + a b c d e ! ^ . f 6 .       ",
+"    . g = = h i + + + . j k l 4 . m . . .       ",
+"    . n o p = * q r + s . t u . v . . . . .     ",
+"    . w x . . . y z A B s . . 5 . C D E F .     ",
+"    . G H I J K L . t M N . 6 . O P Q R S .     ",
+"    . > T U V W X J . j . 6 . . Y Z `  ....     ",
+"    . ; A +.@.t #.$.%.. 6 . &.*.. =.-.;.>..     ",
+"    . / ,.'.).. . . . 6 . !.~.{.].. ^./.(..     ",
+"    . / ,.@.. _.:.<.. . [.. }.|.1.2.. 3.4..     ",
+"    . / 5.. _.6.7.8.9.. 0.a.. b.c.N s . d..     ",
+"    . ; . e.f.g.9.h.i.. j.k.l.. T i * s . .     ",
+"    . . m.n.o.p.h._.q.. Q r.s.t.. u.v.w.x.. .   ",
+"    . y.z.o.A.h._.q.. B.C.D.E.F.G.. H.I.J.6 .   ",
+"  . K.L.M.A.h._.q.. N.O.P.Q.R.S.T.U.. V.W.X..   ",
+"  . Y.Z.`.h._.q..  +.+++@+#+$+%+&+*+=+. . .     ",
+"  . -+h.;+K.q.. >+,+'+)+!+!+!+%+~+{+]+^+/+.     ",
+"    . -+-+9.. (+_+:+<+[+}+|+1+2+2+3+<+4+5+.     ",
+"    . . . . . . . . . . . . . . . . . . .       ",
+"                                                "};
+
+
 #if ! GTK_CHECK_VERSION(2,6,0)
 /* XPM */
 const gchar *about16_xpm[] = {
