@@ -1,10 +1,10 @@
 /*
     Video maid
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,20 +13,21 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include <gdk/gdkkeysyms.h>
 #include "command.h"
 #include "file.h"
 #include "general.h"
+#include "menu.h"
 #include "sigfile.h"
+#include "misc/misc.h"
 #include "orz/orzmdi.h"
 
 
 /******************************************************************************
 *                                                                             *
-* ja:シグナル/イベント関数群(タイマ)                                           *
+* ja:シグナル/イベント関数群(タイマ)                                          *
 *                                                                             *
 ******************************************************************************/
 gboolean
