@@ -19,7 +19,7 @@
 #define __VMAID_H__
 
 
-#include "gcommon.h"
+#include "misc/gcommon.h"
 #include "avicore/avicore.h"
 #ifdef G_OS_WIN32
 # include <tchar.h>
