@@ -1,10 +1,10 @@
 /*
     w32loader
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "commctrl.h"
 #include "kernel32.h"
@@ -1319,87 +1318,87 @@ static DWORD WINAPI _TrackMouseEvent (DWORD dwArgv0)
 }
 
 
-W32LdrExport commctrl_exports[] = {
-{FALSE,  8, "CreateMappedBitmap",           CreateMappedBitmap},
-{TRUE,  12, "CreatePropertySheetPage",      CreatePropertySheetPageA},
-{TRUE,  18, "CreatePropertySheetPageA",     CreatePropertySheetPageA},
-{TRUE,  19, "CreatePropertySheetPageW",     CreatePropertySheetPageW},
-{TRUE,  20, "CreateStatusWindow",           CreateStatusWindowA},
-{TRUE,   6, "CreateStatusWindowA",          CreateStatusWindowA},
-{TRUE,  21, "CreateStatusWindowW",          CreateStatusWindowW},
-{FALSE,  7, "CreateToolbar",                CreateToolbar},
-{TRUE,  22, "CreateToolbarEx",              CreateToolbarEx},
-{TRUE,  16, "CreateUpDownControl",          CreateUpDownControl},
-{TRUE,  23, "DestroyPropertySheetPage",     DestroyPropertySheetPage},
-{FALSE, 24, "DllGetVersion",                commctrl_DllGetVersion},
-{FALSE, 25, "DllInstall",                   commctrl_DllInstall},
-{FALSE, 15, "DrawInsert",                   DrawInsert},
-{FALSE, 26, "DrawStatusText",               DrawStatusTextA},
-{FALSE,  5, "DrawStatusTextA",              DrawStatusTextA},
-{FALSE, 27, "DrawStatusTextW",              DrawStatusTextW},
-{FALSE, 28, "FlatSB_EnableScrollBar",       FlatSB_EnableScrollBar},
-{FALSE, 29, "FlatSB_GetScrollInfo",         FlatSB_GetScrollInfo},
-{FALSE, 30, "FlatSB_GetScrollPos",          FlatSB_GetScrollPos},
-{FALSE, 31, "FlatSB_GetScrollProp",         FlatSB_GetScrollProp},
-{FALSE, 32, "FlatSB_GetScrollRange",        FlatSB_GetScrollRange},
-{FALSE, 33, "FlatSB_SetScrollInfo",         FlatSB_SetScrollInfo},
-{FALSE, 34, "FlatSB_SetScrollPos",          FlatSB_SetScrollPos},
-{FALSE, 35, "FlatSB_SetScrollProp",         FlatSB_SetScrollProp},
-{FALSE, 36, "FlatSB_SetScrollRange",        FlatSB_SetScrollRange},
-{FALSE, 37, "FlatSB_ShowScrollBar",         FlatSB_ShowScrollBar},
-{FALSE,  4, "GetEffectiveClientRect",       GetEffectiveClientRect},
-{FALSE, 38, "GetMUILanguage",               GetMUILanguage},
-{TRUE,  39, "ImageList_Add",                ImageList_Add},
-{TRUE,  40, "ImageList_AddIcon",            ImageList_AddIcon},
-{TRUE,  41, "ImageList_AddMasked",          ImageList_AddMasked},
-{TRUE,  42, "ImageList_BeginDrag",          ImageList_BeginDrag},
-{TRUE,  43, "ImageList_Copy",               ImageList_Copy},
-{TRUE,  44, "ImageList_Create",             ImageList_Create},
-{TRUE,  45, "ImageList_Destroy",            ImageList_Destroy},
-{TRUE,  46, "ImageList_DragEnter",          ImageList_DragEnter},
-{TRUE,  47, "ImageList_DragLeave",          ImageList_DragLeave},
-{TRUE,  48, "ImageList_DragMove",           ImageList_DragMove},
-{TRUE,  49, "ImageList_DragShowNolock",     ImageList_DragShowNolock},
-{TRUE,  50, "ImageList_Draw",               ImageList_Draw},
-{TRUE,  51, "ImageList_DrawEx",             ImageList_DrawEx},
-{TRUE,  52, "ImageList_DrawIndirect",       ImageList_DrawIndirect},
-{TRUE,  53, "ImageList_Duplicate",          ImageList_Duplicate},
-{TRUE,  54, "ImageList_EndDrag",            ImageList_EndDrag},
-{TRUE,  55, "ImageList_GetBkColor",         ImageList_GetBkColor},
-{TRUE,  56, "ImageList_GetDragImage",       ImageList_GetDragImage},
-{FALSE, 57, "ImageList_GetFlags",           ImageList_GetFlags},
-{TRUE,  58, "ImageList_GetIcon",            ImageList_GetIcon},
-{TRUE,  59, "ImageList_GetIconSize",        ImageList_GetIconSize},
-{TRUE,  60, "ImageList_GetImageCount",      ImageList_GetImageCount},
-{TRUE,  61, "ImageList_GetImageInfo",       ImageList_GetImageInfo},
-{FALSE, 62, "ImageList_GetImageRect",       ImageList_GetImageRect},
-{TRUE,  63, "ImageList_LoadImage",          ImageList_LoadImageA},
-{TRUE,  64, "ImageList_LoadImageA",         ImageList_LoadImageA},
-{TRUE,  65, "ImageList_LoadImageW",         ImageList_LoadImageW},
-{TRUE,  66, "ImageList_Merge",              ImageList_Merge},
-{TRUE,  67, "ImageList_Read",               ImageList_Read},
-{TRUE,  68, "ImageList_Remove",             ImageList_Remove},
-{TRUE,  69, "ImageList_Replace",            ImageList_Replace},
-{TRUE,  70, "ImageList_ReplaceIcon",        ImageList_ReplaceIcon},
-{TRUE,  75, "ImageList_SetBkColor",         ImageList_SetBkColor},
-{TRUE,  76, "ImageList_SetDragCursorImage", ImageList_SetDragCursorImage},
-{FALSE, 77, "ImageList_SetFilter",          ImageList_SetFilter},
-{FALSE, 78, "ImageList_SetFlags",           ImageList_SetFlags},
-{TRUE,  79, "ImageList_SetIconSize",        ImageList_SetIconSize},
-{TRUE,  80, "ImageList_SetImageCount",      ImageList_SetImageCount},
-{TRUE,  81, "ImageList_SetOverlayImage",    ImageList_SetOverlayImage},
-{TRUE,  82, "ImageList_Write",              ImageList_Write},
-{TRUE,  17, "InitCommonControls",           InitCommonControls},
-{TRUE,  83, "InitCommonControlsEx",         InitCommonControlsEx},
-{FALSE, 84, "InitMUILanguage",              InitMUILanguage},
-{FALSE, 85, "InitializeFlatSB",             InitializeFlatSB},
-{FALSE, 14, "LBItemFromPt",                 LBItemFromPt},
-{FALSE, 13, "MakeDragList",                 MakeDragList},
-{FALSE,  2, "MenuHelp",                     MenuHelp},
-{TRUE,  86, "PropertySheet",                PropertySheetA},
-{TRUE,  87, "PropertySheetA",               PropertySheetA},
-{TRUE,  88, "PropertySheetW",               PropertySheetW},
-{FALSE,  3, "ShowHideMenuCtl",              ShowHideMenuCtl},
-{FALSE, 89, "UninitializeFlatSB",           UninitializeFlatSB},
-{FALSE, 90, "_TrackMouseEvent",             _TrackMouseEvent},
-{FALSE,  0, NULL,                           NULL}};
+W32LdrExport w32ldr_commctrl_exports[] = {
+{-1,  8, "CreateMappedBitmap",           CreateMappedBitmap},
+{ 0, 12, "CreatePropertySheetPage",      CreatePropertySheetPageA},
+{ 0, 18, "CreatePropertySheetPageA",     CreatePropertySheetPageA},
+{ 0, 19, "CreatePropertySheetPageW",     CreatePropertySheetPageW},
+{ 0, 20, "CreateStatusWindow",           CreateStatusWindowA},
+{ 0,  6, "CreateStatusWindowA",          CreateStatusWindowA},
+{ 0, 21, "CreateStatusWindowW",          CreateStatusWindowW},
+{-1,  7, "CreateToolbar",                CreateToolbar},
+{ 0, 22, "CreateToolbarEx",              CreateToolbarEx},
+{ 0, 16, "CreateUpDownControl",          CreateUpDownControl},
+{ 0, 23, "DestroyPropertySheetPage",     DestroyPropertySheetPage},
+{-1, 24, "DllGetVersion",                commctrl_DllGetVersion},
+{-1, 25, "DllInstall",                   commctrl_DllInstall},
+{-1, 15, "DrawInsert",                   DrawInsert},
+{-1, 26, "DrawStatusText",               DrawStatusTextA},
+{-1,  5, "DrawStatusTextA",              DrawStatusTextA},
+{-1, 27, "DrawStatusTextW",              DrawStatusTextW},
+{-1, 28, "FlatSB_EnableScrollBar",       FlatSB_EnableScrollBar},
+{-1, 29, "FlatSB_GetScrollInfo",         FlatSB_GetScrollInfo},
+{-1, 30, "FlatSB_GetScrollPos",          FlatSB_GetScrollPos},
+{-1, 31, "FlatSB_GetScrollProp",         FlatSB_GetScrollProp},
+{-1, 32, "FlatSB_GetScrollRange",        FlatSB_GetScrollRange},
+{-1, 33, "FlatSB_SetScrollInfo",         FlatSB_SetScrollInfo},
+{-1, 34, "FlatSB_SetScrollPos",          FlatSB_SetScrollPos},
+{-1, 35, "FlatSB_SetScrollProp",         FlatSB_SetScrollProp},
+{-1, 36, "FlatSB_SetScrollRange",        FlatSB_SetScrollRange},
+{-1, 37, "FlatSB_ShowScrollBar",         FlatSB_ShowScrollBar},
+{-1,  4, "GetEffectiveClientRect",       GetEffectiveClientRect},
+{-1, 38, "GetMUILanguage",               GetMUILanguage},
+{ 0, 39, "ImageList_Add",                ImageList_Add},
+{ 0, 40, "ImageList_AddIcon",            ImageList_AddIcon},
+{ 0, 41, "ImageList_AddMasked",          ImageList_AddMasked},
+{ 0, 42, "ImageList_BeginDrag",          ImageList_BeginDrag},
+{ 0, 43, "ImageList_Copy",               ImageList_Copy},
+{ 0, 44, "ImageList_Create",             ImageList_Create},
+{ 0, 45, "ImageList_Destroy",            ImageList_Destroy},
+{ 0, 46, "ImageList_DragEnter",          ImageList_DragEnter},
+{ 0, 47, "ImageList_DragLeave",          ImageList_DragLeave},
+{ 0, 48, "ImageList_DragMove",           ImageList_DragMove},
+{ 0, 49, "ImageList_DragShowNolock",     ImageList_DragShowNolock},
+{ 0, 50, "ImageList_Draw",               ImageList_Draw},
+{ 0, 51, "ImageList_DrawEx",             ImageList_DrawEx},
+{ 0, 52, "ImageList_DrawIndirect",       ImageList_DrawIndirect},
+{ 0, 53, "ImageList_Duplicate",          ImageList_Duplicate},
+{ 0, 54, "ImageList_EndDrag",            ImageList_EndDrag},
+{ 0, 55, "ImageList_GetBkColor",         ImageList_GetBkColor},
+{ 0, 56, "ImageList_GetDragImage",       ImageList_GetDragImage},
+{-1, 57, "ImageList_GetFlags",           ImageList_GetFlags},
+{ 0, 58, "ImageList_GetIcon",            ImageList_GetIcon},
+{ 0, 59, "ImageList_GetIconSize",        ImageList_GetIconSize},
+{ 0, 60, "ImageList_GetImageCount",      ImageList_GetImageCount},
+{ 0, 61, "ImageList_GetImageInfo",       ImageList_GetImageInfo},
+{-1, 62, "ImageList_GetImageRect",       ImageList_GetImageRect},
+{ 0, 63, "ImageList_LoadImage",          ImageList_LoadImageA},
+{ 0, 64, "ImageList_LoadImageA",         ImageList_LoadImageA},
+{ 0, 65, "ImageList_LoadImageW",         ImageList_LoadImageW},
+{ 0, 66, "ImageList_Merge",              ImageList_Merge},
+{ 0, 67, "ImageList_Read",               ImageList_Read},
+{ 0, 68, "ImageList_Remove",             ImageList_Remove},
+{ 0, 69, "ImageList_Replace",            ImageList_Replace},
+{ 0, 70, "ImageList_ReplaceIcon",        ImageList_ReplaceIcon},
+{ 0, 75, "ImageList_SetBkColor",         ImageList_SetBkColor},
+{ 0, 76, "ImageList_SetDragCursorImage", ImageList_SetDragCursorImage},
+{-1, 77, "ImageList_SetFilter",          ImageList_SetFilter},
+{-1, 78, "ImageList_SetFlags",           ImageList_SetFlags},
+{ 0, 79, "ImageList_SetIconSize",        ImageList_SetIconSize},
+{ 0, 80, "ImageList_SetImageCount",      ImageList_SetImageCount},
+{ 0, 81, "ImageList_SetOverlayImage",    ImageList_SetOverlayImage},
+{ 0, 82, "ImageList_Write",              ImageList_Write},
+{ 0, 17, "InitCommonControls",           InitCommonControls},
+{ 0, 83, "InitCommonControlsEx",         InitCommonControlsEx},
+{-1, 84, "InitMUILanguage",              InitMUILanguage},
+{-1, 85, "InitializeFlatSB",             InitializeFlatSB},
+{-1, 14, "LBItemFromPt",                 LBItemFromPt},
+{-1, 13, "MakeDragList",                 MakeDragList},
+{-1,  2, "MenuHelp",                     MenuHelp},
+{ 0, 86, "PropertySheet",                PropertySheetA},
+{ 0, 87, "PropertySheetA",               PropertySheetA},
+{ 0, 88, "PropertySheetW",               PropertySheetW},
+{-1,  3, "ShowHideMenuCtl",              ShowHideMenuCtl},
+{-1, 89, "UninitializeFlatSB",           UninitializeFlatSB},
+{-1, 90, "_TrackMouseEvent",             _TrackMouseEvent},
+{-1,  0, NULL,                           NULL}};
