@@ -1,10 +1,10 @@
 /*
     w32loader
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "commdlg.h"
 #include "kernel32.h"
@@ -1114,31 +1113,31 @@ static DWORD WINAPI dwOKSubclass (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, D
 }
 
 
-W32LdrExport commdlg_exports[] = {
-{FALSE, 101, "ChooseColorA",                      ChooseColorA},
-{FALSE, 102, "ChooseColorW",                      ChooseColorW},
-{TRUE,  103, "ChooseFontA",                       ChooseFontA},
-{TRUE,  104, "ChooseFontW",                       ChooseFontW},
-{FALSE, 105, "CommDlgExtendedError",              CommDlgExtendedError},
-{FALSE, 106, "FindTextA",                         FindTextA},
-{FALSE, 107, "FindTextW",                         FindTextW},
-{FALSE, 108, "GetFileTitleA",                     GetFileTitleA},
-{FALSE, 109, "GetFileTitleW",                     GetFileTitleW},
-{TRUE,  110, "GetOpenFileNameA",                  GetOpenFileNameA},
-{TRUE,  111, "GetOpenFileNameW",                  GetOpenFileNameW},
-{TRUE,  112, "GetSaveFileNameA",                  GetSaveFileNameA},
-{TRUE,  113, "GetSaveFileNameW",                  GetSaveFileNameW},
-{FALSE, 114, "LoadAlterBitmap",                   LoadAlterBitmap},
-{FALSE, 115, "PageSetupDlgA",                     PageSetupDlgA},
-{FALSE, 116, "PageSetupDlgW",                     PageSetupDlgW},
-{FALSE, 117, "PrintDlgA",                         PrintDlgA},
-{FALSE, 118, "PrintDlgExA",                       PrintDlgExA},
-{FALSE, 119, "PrintDlgExW",                       PrintDlgExW},
-{FALSE, 120, "PrintDlgW",                         PrintDlgW},
-{FALSE, 121, "ReplaceTextA",                      ReplaceTextA},
-{FALSE, 122, "ReplaceTextW",                      ReplaceTextW},
-{FALSE, 123, "Ssync_ANSI_UNICODE_Struct_For_WOW", Ssync_ANSI_UNICODE_Struct_For_WOW},
-{FALSE, 124, "WantArrows",                        WantArrows},
-{FALSE, 125, "dwLBSubclass",                      dwLBSubclass},
-{FALSE, 126, "dwOKSubclass",                      dwOKSubclass},
-{FALSE,   0, NULL,                                NULL}};
+W32LdrExport w32ldr_commdlg_exports[] = {
+{-1, 101, "ChooseColorA",                      ChooseColorA},
+{-1, 102, "ChooseColorW",                      ChooseColorW},
+{ 0, 103, "ChooseFontA",                       ChooseFontA},
+{ 0, 104, "ChooseFontW",                       ChooseFontW},
+{-1, 105, "CommDlgExtendedError",              CommDlgExtendedError},
+{-1, 106, "FindTextA",                         FindTextA},
+{-1, 107, "FindTextW",                         FindTextW},
+{-1, 108, "GetFileTitleA",                     GetFileTitleA},
+{-1, 109, "GetFileTitleW",                     GetFileTitleW},
+{ 0, 110, "GetOpenFileNameA",                  GetOpenFileNameA},
+{ 0, 111, "GetOpenFileNameW",                  GetOpenFileNameW},
+{ 0, 112, "GetSaveFileNameA",                  GetSaveFileNameA},
+{ 0, 113, "GetSaveFileNameW",                  GetSaveFileNameW},
+{-1, 114, "LoadAlterBitmap",                   LoadAlterBitmap},
+{-1, 115, "PageSetupDlgA",                     PageSetupDlgA},
+{-1, 116, "PageSetupDlgW",                     PageSetupDlgW},
+{-1, 117, "PrintDlgA",                         PrintDlgA},
+{-1, 118, "PrintDlgExA",                       PrintDlgExA},
+{-1, 119, "PrintDlgExW",                       PrintDlgExW},
+{-1, 120, "PrintDlgW",                         PrintDlgW},
+{-1, 121, "ReplaceTextA",                      ReplaceTextA},
+{-1, 122, "ReplaceTextW",                      ReplaceTextW},
+{-1, 123, "Ssync_ANSI_UNICODE_Struct_For_WOW", Ssync_ANSI_UNICODE_Struct_For_WOW},
+{-1, 124, "WantArrows",                        WantArrows},
+{-1, 125, "dwLBSubclass",                      dwLBSubclass},
+{-1, 126, "dwOKSubclass",                      dwOKSubclass},
+{-1,   0, NULL,                                NULL}};
