@@ -64,7 +64,7 @@ w32edit_DefWindowProc (HWND   hWnd,
           return MAKELRESULT (st, ed);
         }
       case EM_SETSEL:
-        if (GTK_IS_TEXT_VIEW (edit))
+        if (!GTK_IS_TEXT_VIEW (edit))
           gtk_editable_select_region (GTK_EDITABLE (edit), wParam, lParam);
         return 0;
       case EM_GETRECT:
@@ -154,19 +154,21 @@ w32edit_DefWindowProc (HWND   hWnd,
         {
           gchar *utf8str;
 
-          utf8str = wd->widechar ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam),
+          utf8str = lParam ? wd->widechar
+                           ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam),
                                                         -1, NULL, NULL, NULL)
-                            : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam));
+                           : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam))
+                           : g_strdup ("");
           if (GTK_IS_TEXT_VIEW (edit))
             {
               GtkTextIter start, end;
               GtkTextBuffer *buffer;
 
               buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (edit));
-              if (gtk_text_buffer_get_selection_bounds (buffer, &start, &end))
-                gtk_text_buffer_delete (buffer, &start, &end);
-              gtk_text_buffer_insert_at_cursor (buffer,
-                                                utf8str, g_strlen (utf8str));
+              if (gtk_text_buffer_get_selection_bounds (buffer, &start, &end)){
+                gtk_text_buffer_delete (buffer, &start, &end);}
+              if (utf8str)
+                gtk_text_buffer_insert_at_cursor (buffer, utf8str, -1);
             }
           else
             {
@@ -174,7 +176,8 @@ w32edit_DefWindowProc (HWND   hWnd,
 
               gtk_editable_delete_selection (GTK_EDITABLE (edit));
               pos = gtk_editable_get_position (GTK_EDITABLE (edit));
-              gtk_editable_insert_text (GTK_EDITABLE (edit),
+              if (utf8str)
+                gtk_editable_insert_text (GTK_EDITABLE (edit),
                                             utf8str, g_strlen (utf8str), &pos);
             }
           g_free (utf8str);
@@ -440,9 +443,11 @@ w32edit_DefWindowProc (HWND   hWnd,
         {
           gchar *utf8str;
 
-          utf8str = wd->widechar ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam),
+          utf8str = lParam ? wd->widechar
+                           ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam),
                                                         -1, NULL, NULL, NULL)
-                            : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam));
+                           : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam))
+                           : g_strdup ("");
           if (GTK_IS_TEXT_VIEW (edit))
             gtk_text_buffer_set_text
                 (gtk_text_view_get_buffer (GTK_TEXT_VIEW (edit)), utf8str, -1);
@@ -583,6 +588,7 @@ w32ldr_control_create_edit (const gchar    *windowname,
     {
       /* ja:テキストビュー */
       GtkTextBuffer *buffer;
+      GtkTextIter iter;
       GtkWidget *scroll;
 
       edit = gtk_text_view_new ();
@@ -593,13 +599,17 @@ w32ldr_control_create_edit (const gchar    *windowname,
       gtk_text_view_set_editable (GTK_TEXT_VIEW (edit),
                                                     !(ES_READONLY & style));
       buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (edit));
-      g_signal_connect (G_OBJECT (buffer), "changed",
-                                    G_CALLBACK (w32edit_buffer_changed), edit);
+      gtk_text_buffer_set_text (buffer, "", -1);
+      gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
+      gtk_text_buffer_place_cursor (buffer, &iter);
+      gtk_widget_show (edit);
       /* ja:スクロールウインドウ */
       scroll = gtk_scrolled_window_new (NULL, NULL);
       gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
                                 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
       gtk_container_add (GTK_CONTAINER (scroll), edit);
+      g_signal_connect (G_OBJECT (buffer), "changed",
+                                G_CALLBACK (w32edit_buffer_changed), scroll);
       wd->focus = edit;
       widget = scroll;
     }
