@@ -36,6 +36,12 @@
 #include "misc/fileio.h"
 #include "misc/peimage.h"
 #include "misc/profile.h"
+#ifdef HAVE_SYS_MMAN_H
+# include <sys/mman.h>
+#endif /* HAVE_SYS_MMAN_H */
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif /* HAVE_UNISTD_H */
 
 
 #define USE_DEBUG 1
@@ -113,22 +119,26 @@ w32ldr_module_callback_system (PeProcess *process,
         gsize leng, leng_head, leng_code, leng_data;
         LPDWORD lpdwSignature, lpdwFunction, lpdwName;
         LPWORD lpwOrdinal;
-        PIMAGE_DOS_HEADER pidh;
-        PIMAGE_FILE_HEADER pifh;
-        PIMAGE_OPTIONAL_HEADER pioh;
-        PIMAGE_SECTION_HEADER pish;
-        PIMAGE_EXPORT_DIRECTORY pied;
+        ImageDosHeader *idh;
+        ImageFileHeader *ifh;
+        ImageOptionalHeader *ioh;
+        ImageSectionHeader *ish;
+        ImageExportDirectory *ied;
+#if defined (HAVE_SYS_MMAN_H) && defined (HAVE_UNISTD_H)
+        gint pagesize;
+        guint addr;
+#endif /* defined (HAVE_SYS_MMAN_H) && defined (HAVE_UNISTD_H) */
 #ifdef USE_DEBUG
         gchar *r;
 #endif /* USE_DEBUG */
 
-        leng_head = sizeof (IMAGE_DOS_HEADER)
+        leng_head = sizeof (ImageDosHeader)
                   + sizeof (DWORD)
-                  + sizeof (IMAGE_FILE_HEADER)
-                  + sizeof (IMAGE_OPTIONAL_HEADER)
-                  + sizeof (IMAGE_SECTION_HEADER);
+                  + sizeof (ImageFileHeader)
+                  + sizeof (ImageOptionalHeader)
+                  + sizeof (ImageSectionHeader);
         leng_code = 0;
-        leng_data = sizeof (IMAGE_EXPORT_DIRECTORY)
+        leng_data = sizeof (ImageExportDirectory)
                                                 + g_strlen (osdll[i].name) + 1;
         for (j = 0; osdll[i].exports[j].func; j++)
           if (osdll[i].exports[j].implement >= 0)
@@ -154,15 +164,22 @@ w32ldr_module_callback_system (PeProcess *process,
         leng_data += (ordinal_max - ordinal_min + 1) * sizeof (DWORD);
         leng = leng_head + leng_code + leng_data;
         image = g_malloc0 (leng);
+#if defined (HAVE_SYS_MMAN_H) && defined (HAVE_UNISTD_H)
+        pagesize = sysconf (_SC_PAGE_SIZE);
+        addr = GPOINTER_TO_UINT (image) / pagesize * pagesize;
+        mprotect (GUINT_TO_POINTER (addr),
+            (GPOINTER_TO_UINT (image) + leng + pagesize - 1)
+            / pagesize * pagesize - addr, PROT_READ | PROT_WRITE | PROT_EXEC);
+#endif /* defined (HAVE_SYS_MMAN_H) && defined (HAVE_UNISTD_H) */
         /* ja:ポインタ */
-        pidh = (PIMAGE_DOS_HEADER)image;
-        lpdwSignature = (LPDWORD)(pidh + 1);
-        pifh = (PIMAGE_FILE_HEADER)(lpdwSignature + 1);
-        pioh = (PIMAGE_OPTIONAL_HEADER)(pifh + 1);
-        pish = (PIMAGE_SECTION_HEADER)(pioh + 1);
-        p = (guint8 *)(pish + 1);
-        pied = (PIMAGE_EXPORT_DIRECTORY)(p + leng_code);
-        lpdwFunction = (LPDWORD)(pied + 1);
+        idh = (ImageDosHeader *)image;
+        lpdwSignature = (LPDWORD)(idh + 1);
+        ifh = (ImageFileHeader *)(lpdwSignature + 1);
+        ioh = (ImageOptionalHeader *)(ifh + 1);
+        ish = (ImageSectionHeader *)(ioh + 1);
+        p = (guint8 *)(ish + 1);
+        ied = (ImageExportDirectory *)(p + leng_code);
+        lpdwFunction = (LPDWORD)(ied + 1);
         lpdwName = lpdwFunction + ordinal_max - ordinal_min + 1;
         lpwOrdinal = (LPWORD)(lpdwName + num);
         q = (gchar *)(lpwOrdinal + num);
@@ -170,58 +187,60 @@ w32ldr_module_callback_system (PeProcess *process,
         r = q;
 #endif /* USE_DEBUG */
         /* ja:設定 */
-        pidh->e_magic = IMAGE_DOS_SIGNATURE;
-        pidh->e_lfanew = sizeof (IMAGE_DOS_HEADER);
-        *lpdwSignature = IMAGE_NT_SIGNATURE;
-        pifh->Machine = IMAGE_FILE_MACHINE_I386;
-        pifh->NumberOfSections = 1;
-        pifh->SizeOfOptionalHeader = sizeof (IMAGE_OPTIONAL_HEADER);
-        pifh->Characteristics = IMAGE_FILE_EXECUTABLE_IMAGE
-                              | IMAGE_FILE_LINE_NUMS_STRIPPED
-                              | IMAGE_FILE_LOCAL_SYMS_STRIPPED
-                              | IMAGE_FILE_32BIT_MACHINE
-                              | IMAGE_FILE_DLL;
-        pioh->Magic = IMAGE_NT_OPTIONAL_HDR_MAGIC;
-        pioh->SizeOfCode = leng_code;
-        pioh->SizeOfInitializedData = leng_data;
-        pioh->BaseOfCode = leng_head;
-        pioh->BaseOfData = leng_head + leng_code;
-        pioh->ImageBase = 0x10000000;
-        pioh->SectionAlignment = 1;
-        pioh->FileAlignment = 1;
-        pioh->MajorOperatingSystemVersion = 4;
-        pioh->MinorOperatingSystemVersion = 0;
-        pioh->MajorSubsystemVersion = 4;
-        pioh->MinorSubsystemVersion = 0;
-        pioh->SizeOfImage = leng;
-        pioh->SizeOfHeaders = leng_head;
-        pioh->Subsystem = IMAGE_SUBSYSTEM_WINDOWS_GUI;
-        pioh->SizeOfStackReserve = 0x100000;
-        pioh->SizeOfStackCommit = 0x1000;
-        pioh->SizeOfHeapReserve = 0x100000;
-        pioh->SizeOfHeapCommit = 0x1000;
-        pioh->NumberOfRvaAndSizes = IMAGE_NUMBEROF_DIRECTORY_ENTRIES;
-        pioh->DataDirectory[IMAGE_DIRECTORY_ENTRY_EXPORT].VirtualAddress
-                                                    = leng_head + leng_code;
-        pioh->DataDirectory[IMAGE_DIRECTORY_ENTRY_EXPORT].Size = leng_data;
-        pish->Misc.VirtualSize = leng_code + leng_data;
-        pish->VirtualAddress = leng_head;
-        pish->SizeOfRawData = leng_code + leng_data;
-        pish->PointerToRawData = leng_head;
-        pish->Characteristics = IMAGE_SCN_CNT_CODE
-                              | IMAGE_SCN_CNT_INITIALIZED_DATA
-                              | IMAGE_SCN_MEM_EXECUTE
-                              | IMAGE_SCN_MEM_READ;
-        pied->Name = GPOINTER_TO_UINT (q) - GPOINTER_TO_UINT (image);
-        pied->Base = ordinal_min;
-        pied->NumberOfFunctions = ordinal_max - ordinal_min + 1;
-        pied->NumberOfNames = num;
-        pied->AddressOfFunctions = GPOINTER_TO_UINT (lpdwFunction)
-                                                    - GPOINTER_TO_UINT (image);
-        pied->AddressOfNames = GPOINTER_TO_UINT (lpdwName)
-                                                    - GPOINTER_TO_UINT (image);
-        pied->AddressOfNameOrdinals = GPOINTER_TO_UINT (lpwOrdinal)
-                                                    - GPOINTER_TO_UINT (image);
+        idh_set_magic (idh, PEIMAGE_DOS_SIGNATURE);
+        idh_set_lfanew (idh, sizeof (ImageDosHeader));
+        *lpdwSignature = PEIMAGE_NT_SIGNATURE;
+        ifh_set_machine (ifh, PEIMAGE_FILE_MACHINE_I386);
+        ifh_set_number_of_sections (ifh, 1);
+        ifh_set_size_of_optional_header (ifh, sizeof (ImageOptionalHeader));
+        ifh_set_characteristics (ifh, PEIMAGE_FILE_EXECUTABLE_IMAGE
+                                    | PEIMAGE_FILE_LINE_NUMS_STRIPPED
+                                    | PEIMAGE_FILE_LOCAL_SYMS_STRIPPED
+                                    | PEIMAGE_FILE_32BIT_MACHINE
+                                    | PEIMAGE_FILE_DLL);
+        ioh_set_magic (ioh, PEIMAGE_NT_OPTIONAL_HDR_MAGIC);
+        ioh_set_size_of_code (ioh, leng_code);
+        ioh_set_size_of_initialized_data (ioh, leng_data);
+        ioh_set_base_of_code (ioh, leng_head);
+        ioh_set_base_of_data (ioh, leng_head + leng_code);
+        ioh_set_image_base (ioh, 0x10000000);
+        ioh_set_section_alignment (ioh, 1);
+        ioh_set_file_alignment (ioh, 1);
+        ioh_set_major_operating_system_version (ioh, 4);
+        ioh_set_minor_operating_system_version (ioh, 0);
+        ioh_set_major_subsystem_version (ioh, 4);
+        ioh_set_minor_subsystem_version (ioh, 0);
+        ioh_set_size_of_image (ioh, leng);
+        ioh_set_size_of_headers (ioh, leng_head);
+        ioh_set_subsystem (ioh, PEIMAGE_SUBSYSTEM_WINDOWS_GUI);
+        ioh_set_size_of_stack_reserve (ioh, 0x100000);
+        ioh_set_size_of_stack_commit (ioh, 0x1000);
+        ioh_set_size_of_heap_reserve (ioh, 0x100000);
+        ioh_set_size_of_heap_commit (ioh, 0x1000);
+        ioh_set_number_of_rva_and_sizes (ioh,
+                                        PEIMAGE_NUMBEROF_DIRECTORY_ENTRIES);
+        ioh_set_data_directory_virtual_address (ioh,
+                        PEIMAGE_DIRECTORY_ENTRY_EXPORT, leng_head + leng_code);
+        ioh_set_data_directory_size (ioh,
+                                    PEIMAGE_DIRECTORY_ENTRY_EXPORT, leng_data);
+        ish_set_virtual_size (ish, leng_code + leng_data);
+        ish_set_virtual_address (ish, leng_head);
+        ish_set_size_of_raw_data (ish, leng_code + leng_data);
+        ish_set_pointer_to_raw_data (ish, leng_head);
+        ish_set_characteristics (ish, PEIMAGE_SCN_CNT_CODE
+                                    | PEIMAGE_SCN_CNT_INITIALIZED_DATA
+                                    | PEIMAGE_SCN_MEM_EXECUTE
+                                    | PEIMAGE_SCN_MEM_READ);
+        ied_set_name(ied, GPOINTER_TO_UINT (q) - GPOINTER_TO_UINT (image));
+        ied_set_base (ied, ordinal_min);
+        ied_set_number_of_functions (ied, ordinal_max - ordinal_min + 1);
+        ied_set_number_of_names (ied, num);
+        ied_set_address_of_functions (ied, GPOINTER_TO_UINT (lpdwFunction)
+                                                - GPOINTER_TO_UINT (image));
+        ied_set_address_of_names (ied, GPOINTER_TO_UINT (lpdwName)
+                                                - GPOINTER_TO_UINT (image));
+        ied_set_address_of_name_ordinals (ied, GPOINTER_TO_UINT (lpwOrdinal)
+                                                - GPOINTER_TO_UINT (image));
         g_strcpy (q, osdll[i].name);
         q += g_strlen (osdll[i].name) + 1;
         for (j = 0; osdll[i].exports[j].func; j++)
@@ -309,6 +328,30 @@ w32ldr_module_callback_entry (PeProcess      *process,
                               const gboolean  reason,
                               gpointer        user_data)
 {
+#if defined (HAVE_SYS_MMAN_H) && defined (HAVE_UNISTD_H)
+  gint i, pagesize;
+  gssize length = 0;
+  guint16 sections;
+  guint addr;
+  ImageSectionHeader *ish;
+
+  pagesize = sysconf (_SC_PAGE_SIZE);
+  sections = pe_ifh_get_number_of_sections (image);
+  ish = pe_image_section_header (image);
+  for (i = 0; i < sections; i++)
+    {
+      gssize leng;
+
+      leng = ish_get_virtual_size (ish) + ish_get_virtual_address (ish);
+      if (length < leng)
+        length = leng;
+      ish++;
+    }
+  addr = GPOINTER_TO_UINT (image) / pagesize * pagesize;
+  mprotect (GUINT_TO_POINTER (addr),
+            (GPOINTER_TO_UINT (image) + length + pagesize - 1)
+            / pagesize * pagesize - addr, PROT_READ | PROT_WRITE | PROT_EXEC);
+#endif /* defined (HAVE_SYS_MMAN_H) && defined (HAVE_UNISTD_H) */
   if (pe_ifh_get_characteristics (image) & IMAGE_FILE_DLL)
     {
       DllEntryProc DllMain;
