@@ -1,10 +1,10 @@
 /*
     w32loader
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2009 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "w32private.h"
 #include "commctrl.h"
@@ -820,17 +819,12 @@ static void
 w32tool_destroy (GtkWidget *widget,
                  gpointer   user_data)
 {
-  GList *glist;
   W32LdrToolData *td;
 
   td = g_object_get_data (G_OBJECT (widget), "user_data");
-  for (glist = g_list_first (td->glist_pixbuf); glist;
-                                                glist = g_list_next (glist))
-    g_object_unref (G_OBJECT (glist->data));
+  g_list_foreach (td->glist_pixbuf, (GFunc)g_object_unref, NULL);
   g_list_free (td->glist_pixbuf);
-  for (glist = g_list_first (td->glist_string); glist;
-                                                glist = g_list_next (glist))
-    g_free (glist->data);
+  g_list_foreach (td->glist_string, (GFunc)g_free, NULL);
   g_list_free (td->glist_string);
 }
 
