@@ -1,10 +1,10 @@
 /*
     w32loader
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "winmm.h"
 #include "advapi32.h"
@@ -68,7 +67,7 @@ typedef UINT MMRESULT;
 
 struct _HDRVR
 {
-  W32LdrModule *module;
+  HMODULE hModule;
   LONG lOpenID;
   DWORD dwDriverId;
   LONG CALLBACK (*DriverProc)(DWORD, HDRVR, UINT, LONG, LONG);
@@ -76,16 +75,16 @@ struct _HDRVR
 
 
 /* CloseDriver ordinal = 3, argument = 12 */
-LRESULT WINAPI CloseDriver (HDRVR hdrvr, LONG lParam1, LONG lParam2)
+LRESULT WINAPI CloseDriver (HDRVR hDrvr, LONG lParam1, LONG lParam2)
 {
-  if (hdrvr)
+  if (hDrvr)
     {
-      hdrvr->DriverProc (hdrvr->dwDriverId, hdrvr, DRV_CLOSE, 0, 0);
-      hdrvr->DriverProc (hdrvr->lOpenID, hdrvr, DRV_CLOSE, 0, 0);
-      hdrvr->DriverProc (0, hdrvr, DRV_DISABLE, 0, 0);
-      hdrvr->DriverProc (0, hdrvr, DRV_FREE, 0, 0);
-      w32ldr_module_free (hdrvr->module);
-      g_free (hdrvr);
+      hDrvr->DriverProc (hDrvr->dwDriverId, hDrvr, DRV_CLOSE, 0, 0);
+      hDrvr->DriverProc (hDrvr->lOpenID, hDrvr, DRV_CLOSE, 0, 0);
+      hDrvr->DriverProc (0, hDrvr, DRV_DISABLE, 0, 0);
+      hDrvr->DriverProc (0, hDrvr, DRV_FREE, 0, 0);
+      FreeLibrary (hDrvr->hModule);
+      g_free (hDrvr);
     }
   return TRUE;
 }
@@ -129,9 +128,9 @@ static DWORD WINAPI DrvGetModuleHandle (DWORD dwArgv0)
 
 
 /* GetDriverModuleHandle ordinal = 7, argument = 4 */
-HMODULE WINAPI GetDriverModuleHandle (HDRVR hdrvr)
+HMODULE WINAPI GetDriverModuleHandle (HDRVR hDrvr)
 {
-  return hdrvr ? ((W32LdrModule *)hdrvr->module) + 1 : NULL;
+  return hDrvr ? hDrvr->hModule : NULL;
 }
 
 
@@ -166,62 +165,41 @@ static DWORD WINAPI NotifyCallbackData (DWORD dwArgv0, DWORD dwArgv1, DWORD dwAr
 /* OpenDriver ordinal = 12, argument = 12 */
 HDRVR WINAPI OpenDriver (LPCWSTR lpDriverName, LPCWSTR lpSectionName, LONG lParam)
 {
-  gchar *file, *utf8str;
-  HDRVR hdrvr;
+  HDRVR hDrvr;
   HKEY hKey;
 
-  hdrvr = g_malloc (sizeof (struct _HDRVR));
-  utf8str = lpDriverName ? g_utf16_to_utf8 (lpDriverName, -1, NULL, NULL, NULL)
-                         : NULL;
-  file = utf8str ? g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL) : NULL;
-  g_free (utf8str);
-  hdrvr->module = w32ldr_module_load_library (file, TRUE);
-  g_free (file);
-  if (!hdrvr->module && RegOpenKeyEx (HKEY_LOCAL_MACHINE,
+  hDrvr = g_malloc (sizeof (struct _HDRVR));
+  hDrvr->hModule = LoadLibraryW (lpDriverName);
+  if (!hDrvr->hModule && RegOpenKeyEx (HKEY_LOCAL_MACHINE,
         _T("Software\\Microsoft\\Windows NT\\CurrentVersion\\Drivers32"), 0,
                                     KEY_QUERY_VALUE, &hKey) == ERROR_SUCCESS)
     {
-      DWORD dwType, dwValue = MAX_PATH;
-#ifdef UNICODE
+      DWORD dwType, dwValue = MAX_PATH * sizeof (WCHAR);
       WCHAR szValue[MAX_PATH];
 
-      if (RegQueryValueEx (hKey, lpDriverName, NULL,
-            &dwType, szValue, &dwValue) == ERROR_SUCCESS && dwType == REG_SZ)
-        {
-          file = w32ldr_filename_from_wc (szValue);
-#else /* not UNICODE */
-      CHAR szName[MAX_PATH], szValue[MAX_PATH];
-
-      WideCharToMultiByte (CP_ACP, 0, lpDriverName, -1,
-                                                szName, MAX_PATH, NULL, NULL);
-      if (RegQueryValueEx (hKey, szName, NULL, &dwType,
-            (LPBYTE)szValue, &dwValue) == ERROR_SUCCESS && dwType == REG_SZ)
-        {
-          file = w32ldr_filename_from_mb (szValue);
-#endif /* not UNICODE */
-          hdrvr->module = w32ldr_module_load_library (file, TRUE);
-          g_free (file);
-        }
+      if (RegQueryValueExW (hKey, lpDriverName, NULL, &dwType, (LPBYTE)szValue,
+                                &dwValue) == ERROR_SUCCESS && dwType == REG_SZ)
+        hDrvr->hModule = LoadLibraryW (szValue);
       RegCloseKey (hKey);
     }
-  hdrvr->DriverProc = w32ldr_module_get_func (hdrvr->module, "DriverProc");
-  if (hdrvr->DriverProc)
+  hDrvr->DriverProc = GetProcAddress (hDrvr->hModule, "DriverProc");
+  if (hDrvr->DriverProc)
     {
-      gunichar2 param = '\0';
+      WCHAR wParam = '\0';
 
-      hdrvr->DriverProc (0, hdrvr, DRV_LOAD, 0, 0);
-      hdrvr->DriverProc (0, hdrvr, DRV_ENABLE, 0, 0);
-      hdrvr->lOpenID = hdrvr->DriverProc (0, hdrvr, DRV_OPEN,
-                                                GPOINTER_TO_INT (&param), 0);
-      hdrvr->dwDriverId = hdrvr->DriverProc (0, hdrvr, DRV_OPEN, 0, lParam);
+      hDrvr->DriverProc (0, hDrvr, DRV_LOAD, 0, 0);
+      hDrvr->DriverProc (0, hDrvr, DRV_ENABLE, 0, 0);
+      hDrvr->lOpenID = hDrvr->DriverProc (0, hDrvr, DRV_OPEN,
+                                                GPOINTER_TO_INT (&wParam), 0);
+      hDrvr->dwDriverId = hDrvr->DriverProc (0, hDrvr, DRV_OPEN, 0, lParam);
     }
   else
     {
-      w32ldr_module_free (hdrvr->module);
-      g_free (hdrvr);
-      hdrvr = NULL;
+      FreeLibrary (hDrvr->hModule);
+      g_free (hDrvr);
+      hDrvr = NULL;
     }
-  return hdrvr;
+  return hDrvr;
 }
 
 
@@ -1546,204 +1524,204 @@ static DWORD WINAPI wod32Message (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, D
 }
 
 
-W32LdrExport winmm_exports[] = {
-{TRUE,    3, "CloseDriver",                  CloseDriver},
-{TRUE,    4, "DefDriverProc",                DefDriverProc},
-{FALSE,   5, "DriverCallback",               DriverCallback},
-{FALSE,   6, "DrvGetModuleHandle",           DrvGetModuleHandle},
-{TRUE,    7, "GetDriverModuleHandle",        GetDriverModuleHandle},
-{FALSE,   8, "MigrateAllDrivers",            MigrateAllDrivers},
-{FALSE,   9, "MigrateMidiUser",              MigrateMidiUser},
-{FALSE,  10, "MigrateSoundEvents",           MigrateSoundEvents},
-{FALSE,  11, "NotifyCallbackData",           NotifyCallbackData},
-{TRUE,   12, "OpenDriver",                   OpenDriver},
-{FALSE,  13, "PlaySound",                    PlaySoundA},
-{FALSE,  14, "PlaySoundA",                   PlaySoundA},
-{FALSE,  15, "PlaySoundW",                   PlaySoundW},
-{TRUE,   16, "SendDriverMessage",            SendDriverMessage},
-{FALSE,  17, "WOW32DriverCallback",          WOW32DriverCallback},
-{FALSE,  18, "WOW32ResolveMultiMediaHandle", WOW32ResolveMultiMediaHandle},
-{FALSE,  19, "WOWAppExit",                   WOWAppExit},
-{FALSE,  20, "WinmmLogoff",                  WinmmLogoff},
-{FALSE,  21, "WinmmLogon",                   WinmmLogon},
-{FALSE,  22, "aux32Message",                 aux32Message},
-{FALSE,  23, "auxGetDevCapsA",               auxGetDevCapsA},
-{FALSE,  24, "auxGetDevCapsW",               auxGetDevCapsW},
-{FALSE,  25, "auxGetNumDevs",                auxGetNumDevs},
-{FALSE,  26, "auxGetVolume",                 auxGetVolume},
-{FALSE,  27, "auxOutMessage",                auxOutMessage},
-{FALSE,  28, "auxSetVolume",                 auxSetVolume},
-{FALSE,  29, "joy32Message",                 joy32Message},
-{FALSE,  30, "joyConfigChanged",             joyConfigChanged},
-{FALSE,  31, "joyGetDevCapsA",               joyGetDevCapsA},
-{FALSE,  32, "joyGetDevCapsW",               joyGetDevCapsW},
-{FALSE,  33, "joyGetNumDevs",                joyGetNumDevs},
-{FALSE,  34, "joyGetPos",                    joyGetPos},
-{FALSE,  35, "joyGetPosEx",                  joyGetPosEx},
-{FALSE,  36, "joyGetThreshold",              joyGetThreshold},
-{FALSE,  37, "joyReleaseCapture",            joyReleaseCapture},
-{FALSE,  38, "joySetCapture",                joySetCapture},
-{FALSE,  39, "joySetThreshold",              joySetThreshold},
-{FALSE,  40, "mci32Message",                 mci32Message},
-{FALSE,  41, "mciDriverNotify",              mciDriverNotify},
-{FALSE,  42, "mciDriverYield",               mciDriverYield},
-{FALSE,  43, "mciExecute",                   mciExecute},
-{FALSE,  44, "mciFreeCommandResource",       mciFreeCommandResource},
-{FALSE,  45, "mciGetCreatorTask",            mciGetCreatorTask},
-{FALSE,  46, "mciGetDeviceIDA",              mciGetDeviceIDA},
-{FALSE,  47, "mciGetDeviceIDFromElementIDA", mciGetDeviceIDFromElementIDA},
-{FALSE,  48, "mciGetDeviceIDFromElementIDW", mciGetDeviceIDFromElementIDW},
-{FALSE,  49, "mciGetDeviceIDW",              mciGetDeviceIDW},
-{FALSE,  50, "mciGetDriverData",             mciGetDriverData},
-{FALSE,  51, "mciGetErrorStringA",           mciGetErrorStringA},
-{FALSE,  52, "mciGetErrorStringW",           mciGetErrorStringW},
-{FALSE,  53, "mciGetYieldProc",              mciGetYieldProc},
-{FALSE,  54, "mciLoadCommandResource",       mciLoadCommandResource},
-{FALSE,  55, "mciSendCommandA",              mciSendCommandA},
-{FALSE,  56, "mciSendCommandW",              mciSendCommandW},
-{FALSE,  57, "mciSendStringA",               mciSendStringA},
-{FALSE,  58, "mciSendStringW",               mciSendStringW},
-{FALSE,  59, "mciSetDriverData",             mciSetDriverData},
-{FALSE,  60, "mciSetYieldProc",              mciSetYieldProc},
-{FALSE,  61, "mid32Message",                 mid32Message},
-{FALSE,  62, "midiConnect",                  midiConnect},
-{FALSE,  63, "midiDisconnect",               midiDisconnect},
-{FALSE,  64, "midiInAddBuffer",              midiInAddBuffer},
-{FALSE,  65, "midiInClose",                  midiInClose},
-{FALSE,  66, "midiInGetDevCapsA",            midiInGetDevCapsA},
-{FALSE,  67, "midiInGetDevCapsW",            midiInGetDevCapsW},
-{FALSE,  68, "midiInGetErrorTextA",          midiInGetErrorTextA},
-{FALSE,  69, "midiInGetErrorTextW",          midiInGetErrorTextW},
-{FALSE,  70, "midiInGetID",                  midiInGetID},
-{FALSE,  71, "midiInGetNumDevs",             midiInGetNumDevs},
-{FALSE,  72, "midiInMessage",                midiInMessage},
-{FALSE,  73, "midiInOpen",                   midiInOpen},
-{FALSE,  74, "midiInPrepareHeader",          midiInPrepareHeader},
-{FALSE,  75, "midiInReset",                  midiInReset},
-{FALSE,  76, "midiInStart",                  midiInStart},
-{FALSE,  77, "midiInStop",                   midiInStop},
-{FALSE,  78, "midiInUnprepareHeader",        midiInUnprepareHeader},
-{FALSE,  79, "midiOutCacheDrumPatches",      midiOutCacheDrumPatches},
-{FALSE,  80, "midiOutCachePatches",          midiOutCachePatches},
-{FALSE,  81, "midiOutClose",                 midiOutClose},
-{FALSE,  82, "midiOutGetDevCapsA",           midiOutGetDevCapsA},
-{FALSE,  83, "midiOutGetDevCapsW",           midiOutGetDevCapsW},
-{FALSE,  84, "midiOutGetErrorTextA",         midiOutGetErrorTextA},
-{FALSE,  85, "midiOutGetErrorTextW",         midiOutGetErrorTextW},
-{FALSE,  86, "midiOutGetID",                 midiOutGetID},
-{FALSE,  87, "midiOutGetNumDevs",            midiOutGetNumDevs},
-{FALSE,  88, "midiOutGetVolume",             midiOutGetVolume},
-{FALSE,  89, "midiOutLongMsg",               midiOutLongMsg},
-{FALSE,  90, "midiOutMessage",               midiOutMessage},
-{FALSE,  91, "midiOutOpen",                  midiOutOpen},
-{FALSE,  92, "midiOutPrepareHeader",         midiOutPrepareHeader},
-{FALSE,  93, "midiOutReset",                 midiOutReset},
-{FALSE,  94, "midiOutSetVolume",             midiOutSetVolume},
-{FALSE,  95, "midiOutShortMsg",              midiOutShortMsg},
-{FALSE,  96, "midiOutUnprepareHeader",       midiOutUnprepareHeader},
-{FALSE,  97, "midiStreamClose",              midiStreamClose},
-{FALSE,  98, "midiStreamOpen",               midiStreamOpen},
-{FALSE,  99, "midiStreamOut",                midiStreamOut},
-{FALSE, 100, "midiStreamPause",              midiStreamPause},
-{FALSE, 101, "midiStreamPosition",           midiStreamPosition},
-{FALSE, 102, "midiStreamProperty",           midiStreamProperty},
-{FALSE, 103, "midiStreamRestart",            midiStreamRestart},
-{FALSE, 104, "midiStreamStop",               midiStreamStop},
-{FALSE, 105, "mixerClose",                   mixerClose},
-{FALSE, 106, "mixerGetControlDetailsA",      mixerGetControlDetailsA},
-{FALSE, 107, "mixerGetControlDetailsW",      mixerGetControlDetailsW},
-{FALSE, 108, "mixerGetDevCapsA",             mixerGetDevCapsA},
-{FALSE, 109, "mixerGetDevCapsW",             mixerGetDevCapsW},
-{FALSE, 110, "mixerGetID",                   mixerGetID},
-{FALSE, 111, "mixerGetLineControlsA",        mixerGetLineControlsA},
-{FALSE, 112, "mixerGetLineControlsW",        mixerGetLineControlsW},
-{FALSE, 113, "mixerGetLineInfoA",            mixerGetLineInfoA},
-{FALSE, 114, "mixerGetLineInfoW",            mixerGetLineInfoW},
-{FALSE, 115, "mixerGetNumDevs",              mixerGetNumDevs},
-{FALSE, 116, "mixerMessage",                 mixerMessage},
-{FALSE, 117, "mixerOpen",                    mixerOpen},
-{FALSE, 118, "mixerSetControlDetails",       mixerSetControlDetails},
-{FALSE, 119, "mmDrvInstall",                 mmDrvInstall},
-{FALSE, 120, "mmGetCurrentTask",             mmGetCurrentTask},
-{FALSE, 121, "mmTaskBlock",                  mmTaskBlock},
-{FALSE, 122, "mmTaskCreate",                 mmTaskCreate},
-{FALSE, 123, "mmTaskSignal",                 mmTaskSignal},
-{FALSE, 124, "mmTaskYield",                  mmTaskYield},
-{FALSE, 125, "mmioAdvance",                  mmioAdvance},
-{FALSE, 126, "mmioAscend",                   mmioAscend},
-{FALSE, 127, "mmioClose",                    mmioClose},
-{FALSE, 128, "mmioCreateChunk",              mmioCreateChunk},
-{FALSE, 129, "mmioDescend",                  mmioDescend},
-{FALSE, 130, "mmioFlush",                    mmioFlush},
-{FALSE, 131, "mmioGetInfo",                  mmioGetInfo},
-{FALSE, 132, "mmioInstallIOProcA",           mmioInstallIOProcA},
-{FALSE, 133, "mmioInstallIOProcW",           mmioInstallIOProcW},
-{FALSE, 134, "mmioOpenA",                    mmioOpenA},
-{FALSE, 135, "mmioOpenW",                    mmioOpenW},
-{FALSE, 136, "mmioRead",                     mmioRead},
-{FALSE, 137, "mmioRenameA",                  mmioRenameA},
-{FALSE, 138, "mmioRenameW",                  mmioRenameW},
-{FALSE, 139, "mmioSeek",                     mmioSeek},
-{FALSE, 140, "mmioSendMessage",              mmioSendMessage},
-{FALSE, 141, "mmioSetBuffer",                mmioSetBuffer},
-{FALSE, 142, "mmioSetInfo",                  mmioSetInfo},
-{FALSE, 143, "mmioStringToFOURCCA",          mmioStringToFOURCCA},
-{FALSE, 144, "mmioStringToFOURCCW",          mmioStringToFOURCCW},
-{FALSE, 145, "mmioWrite",                    mmioWrite},
-{FALSE, 146, "mmsystemGetVersion",           mmsystemGetVersion},
-{FALSE, 147, "mod32Message",                 mod32Message},
-{FALSE, 148, "mxd32Message",                 mxd32Message},
-{TRUE,  149, "sndPlaySoundA",                sndPlaySoundA},
-{TRUE,  150, "sndPlaySoundW",                sndPlaySoundW},
-{FALSE, 151, "tid32Message",                 tid32Message},
-{TRUE,  152, "timeBeginPeriod",              timeBeginPeriod},
-{TRUE,  153, "timeEndPeriod",                timeEndPeriod},
-{FALSE, 154, "timeGetDevCaps",               timeGetDevCaps},
-{FALSE, 155, "timeGetSystemTime",            timeGetSystemTime},
-{TRUE,  156, "timeGetTime",                  timeGetTime},
-{FALSE, 157, "timeKillEvent",                timeKillEvent},
-{FALSE, 158, "timeSetEvent",                 timeSetEvent},
-{FALSE, 159, "waveInAddBuffer",              waveInAddBuffer},
-{FALSE, 160, "waveInClose",                  waveInClose},
-{FALSE, 161, "waveInGetDevCapsA",            waveInGetDevCapsA},
-{FALSE, 162, "waveInGetDevCapsW",            waveInGetDevCapsW},
-{FALSE, 163, "waveInGetErrorTextA",          waveInGetErrorTextA},
-{FALSE, 164, "waveInGetErrorTextW",          waveInGetErrorTextW},
-{FALSE, 165, "waveInGetID",                  waveInGetID},
-{FALSE, 166, "waveInGetNumDevs",             waveInGetNumDevs},
-{FALSE, 167, "waveInGetPosition",            waveInGetPosition},
-{FALSE, 168, "waveInMessage",                waveInMessage},
-{FALSE, 169, "waveInOpen",                   waveInOpen},
-{FALSE, 170, "waveInPrepareHeader",          waveInPrepareHeader},
-{FALSE, 171, "waveInReset",                  waveInReset},
-{FALSE, 172, "waveInStart",                  waveInStart},
-{FALSE, 173, "waveInStop",                   waveInStop},
-{FALSE, 174, "waveInUnprepareHeader",        waveInUnprepareHeader},
-{FALSE, 175, "waveOutBreakLoop",             waveOutBreakLoop},
-{FALSE, 176, "waveOutClose",                 waveOutClose},
-{FALSE, 177, "waveOutGetDevCapsA",           waveOutGetDevCapsA},
-{FALSE, 178, "waveOutGetDevCapsW",           waveOutGetDevCapsW},
-{FALSE, 179, "waveOutGetErrorTextA",         waveOutGetErrorTextA},
-{FALSE, 180, "waveOutGetErrorTextW",         waveOutGetErrorTextW},
-{FALSE, 181, "waveOutGetID",                 waveOutGetID},
-{FALSE, 182, "waveOutGetNumDevs",            waveOutGetNumDevs},
-{FALSE, 183, "waveOutGetPitch",              waveOutGetPitch},
-{FALSE, 184, "waveOutGetPlaybackRate",       waveOutGetPlaybackRate},
-{FALSE, 185, "waveOutGetPosition",           waveOutGetPosition},
-{FALSE, 186, "waveOutGetVolume",             waveOutGetVolume},
-{FALSE, 187, "waveOutMessage",               waveOutMessage},
-{FALSE, 188, "waveOutOpen",                  waveOutOpen},
-{FALSE, 189, "waveOutPause",                 waveOutPause},
-{FALSE, 190, "waveOutPrepareHeader",         waveOutPrepareHeader},
-{FALSE, 191, "waveOutReset",                 waveOutReset},
-{FALSE, 192, "waveOutRestart",               waveOutRestart},
-{FALSE, 193, "waveOutSetPitch",              waveOutSetPitch},
-{FALSE, 194, "waveOutSetPlaybackRate",       waveOutSetPlaybackRate},
-{FALSE, 195, "waveOutSetVolume",             waveOutSetVolume},
-{FALSE, 196, "waveOutUnprepareHeader",       waveOutUnprepareHeader},
-{FALSE, 197, "waveOutWrite",                 waveOutWrite},
-{FALSE, 198, "wid32Message",                 wid32Message},
-{FALSE, 199, "winmmDbgOut",                  winmmDbgOut},
-{FALSE, 200, "winmmSetDebugLevel",           winmmSetDebugLevel},
-{FALSE, 201, "wod32Message",                 wod32Message},
-{FALSE,   0, NULL,                           NULL}};
+W32LdrExport w32ldr_winmm_exports[] = {
+{ 0,   3, "CloseDriver",                  CloseDriver},
+{ 0,   4, "DefDriverProc",                DefDriverProc},
+{-1,   5, "DriverCallback",               DriverCallback},
+{-1,   6, "DrvGetModuleHandle",           DrvGetModuleHandle},
+{ 0,   7, "GetDriverModuleHandle",        GetDriverModuleHandle},
+{-1,   8, "MigrateAllDrivers",            MigrateAllDrivers},
+{-1,   9, "MigrateMidiUser",              MigrateMidiUser},
+{-1,  10, "MigrateSoundEvents",           MigrateSoundEvents},
+{-1,  11, "NotifyCallbackData",           NotifyCallbackData},
+{ 0,  12, "OpenDriver",                   OpenDriver},
+{-1,  13, "PlaySound",                    PlaySoundA},
+{-1,  14, "PlaySoundA",                   PlaySoundA},
+{-1,  15, "PlaySoundW",                   PlaySoundW},
+{ 0,  16, "SendDriverMessage",            SendDriverMessage},
+{-1,  17, "WOW32DriverCallback",          WOW32DriverCallback},
+{-1,  18, "WOW32ResolveMultiMediaHandle", WOW32ResolveMultiMediaHandle},
+{-1,  19, "WOWAppExit",                   WOWAppExit},
+{-1,  20, "WinmmLogoff",                  WinmmLogoff},
+{-1,  21, "WinmmLogon",                   WinmmLogon},
+{-1,  22, "aux32Message",                 aux32Message},
+{-1,  23, "auxGetDevCapsA",               auxGetDevCapsA},
+{-1,  24, "auxGetDevCapsW",               auxGetDevCapsW},
+{-1,  25, "auxGetNumDevs",                auxGetNumDevs},
+{-1,  26, "auxGetVolume",                 auxGetVolume},
+{-1,  27, "auxOutMessage",                auxOutMessage},
+{-1,  28, "auxSetVolume",                 auxSetVolume},
+{-1,  29, "joy32Message",                 joy32Message},
+{-1,  30, "joyConfigChanged",             joyConfigChanged},
+{-1,  31, "joyGetDevCapsA",               joyGetDevCapsA},
+{-1,  32, "joyGetDevCapsW",               joyGetDevCapsW},
+{-1,  33, "joyGetNumDevs",                joyGetNumDevs},
+{-1,  34, "joyGetPos",                    joyGetPos},
+{-1,  35, "joyGetPosEx",                  joyGetPosEx},
+{-1,  36, "joyGetThreshold",              joyGetThreshold},
+{-1,  37, "joyReleaseCapture",            joyReleaseCapture},
+{-1,  38, "joySetCapture",                joySetCapture},
+{-1,  39, "joySetThreshold",              joySetThreshold},
+{-1,  40, "mci32Message",                 mci32Message},
+{-1,  41, "mciDriverNotify",              mciDriverNotify},
+{-1,  42, "mciDriverYield",               mciDriverYield},
+{-1,  43, "mciExecute",                   mciExecute},
+{-1,  44, "mciFreeCommandResource",       mciFreeCommandResource},
+{-1,  45, "mciGetCreatorTask",            mciGetCreatorTask},
+{-1,  46, "mciGetDeviceIDA",              mciGetDeviceIDA},
+{-1,  47, "mciGetDeviceIDFromElementIDA", mciGetDeviceIDFromElementIDA},
+{-1,  48, "mciGetDeviceIDFromElementIDW", mciGetDeviceIDFromElementIDW},
+{-1,  49, "mciGetDeviceIDW",              mciGetDeviceIDW},
+{-1,  50, "mciGetDriverData",             mciGetDriverData},
+{-1,  51, "mciGetErrorStringA",           mciGetErrorStringA},
+{-1,  52, "mciGetErrorStringW",           mciGetErrorStringW},
+{-1,  53, "mciGetYieldProc",              mciGetYieldProc},
+{-1,  54, "mciLoadCommandResource",       mciLoadCommandResource},
+{-1,  55, "mciSendCommandA",              mciSendCommandA},
+{-1,  56, "mciSendCommandW",              mciSendCommandW},
+{-1,  57, "mciSendStringA",               mciSendStringA},
+{-1,  58, "mciSendStringW",               mciSendStringW},
+{-1,  59, "mciSetDriverData",             mciSetDriverData},
+{-1,  60, "mciSetYieldProc",              mciSetYieldProc},
+{-1,  61, "mid32Message",                 mid32Message},
+{-1,  62, "midiConnect",                  midiConnect},
+{-1,  63, "midiDisconnect",               midiDisconnect},
+{-1,  64, "midiInAddBuffer",              midiInAddBuffer},
+{-1,  65, "midiInClose",                  midiInClose},
+{-1,  66, "midiInGetDevCapsA",            midiInGetDevCapsA},
+{-1,  67, "midiInGetDevCapsW",            midiInGetDevCapsW},
+{-1,  68, "midiInGetErrorTextA",          midiInGetErrorTextA},
+{-1,  69, "midiInGetErrorTextW",          midiInGetErrorTextW},
+{-1,  70, "midiInGetID",                  midiInGetID},
+{-1,  71, "midiInGetNumDevs",             midiInGetNumDevs},
+{-1,  72, "midiInMessage",                midiInMessage},
+{-1,  73, "midiInOpen",                   midiInOpen},
+{-1,  74, "midiInPrepareHeader",          midiInPrepareHeader},
+{-1,  75, "midiInReset",                  midiInReset},
+{-1,  76, "midiInStart",                  midiInStart},
+{-1,  77, "midiInStop",                   midiInStop},
+{-1,  78, "midiInUnprepareHeader",        midiInUnprepareHeader},
+{-1,  79, "midiOutCacheDrumPatches",      midiOutCacheDrumPatches},
+{-1,  80, "midiOutCachePatches",          midiOutCachePatches},
+{-1,  81, "midiOutClose",                 midiOutClose},
+{-1,  82, "midiOutGetDevCapsA",           midiOutGetDevCapsA},
+{-1,  83, "midiOutGetDevCapsW",           midiOutGetDevCapsW},
+{-1,  84, "midiOutGetErrorTextA",         midiOutGetErrorTextA},
+{-1,  85, "midiOutGetErrorTextW",         midiOutGetErrorTextW},
+{-1,  86, "midiOutGetID",                 midiOutGetID},
+{-1,  87, "midiOutGetNumDevs",            midiOutGetNumDevs},
+{-1,  88, "midiOutGetVolume",             midiOutGetVolume},
+{-1,  89, "midiOutLongMsg",               midiOutLongMsg},
+{-1,  90, "midiOutMessage",               midiOutMessage},
+{-1,  91, "midiOutOpen",                  midiOutOpen},
+{-1,  92, "midiOutPrepareHeader",         midiOutPrepareHeader},
+{-1,  93, "midiOutReset",                 midiOutReset},
+{-1,  94, "midiOutSetVolume",             midiOutSetVolume},
+{-1,  95, "midiOutShortMsg",              midiOutShortMsg},
+{-1,  96, "midiOutUnprepareHeader",       midiOutUnprepareHeader},
+{-1,  97, "midiStreamClose",              midiStreamClose},
+{-1,  98, "midiStreamOpen",               midiStreamOpen},
+{-1,  99, "midiStreamOut",                midiStreamOut},
+{-1, 100, "midiStreamPause",              midiStreamPause},
+{-1, 101, "midiStreamPosition",           midiStreamPosition},
+{-1, 102, "midiStreamProperty",           midiStreamProperty},
+{-1, 103, "midiStreamRestart",            midiStreamRestart},
+{-1, 104, "midiStreamStop",               midiStreamStop},
+{-1, 105, "mixerClose",                   mixerClose},
+{-1, 106, "mixerGetControlDetailsA",      mixerGetControlDetailsA},
+{-1, 107, "mixerGetControlDetailsW",      mixerGetControlDetailsW},
+{-1, 108, "mixerGetDevCapsA",             mixerGetDevCapsA},
+{-1, 109, "mixerGetDevCapsW",             mixerGetDevCapsW},
+{-1, 110, "mixerGetID",                   mixerGetID},
+{-1, 111, "mixerGetLineControlsA",        mixerGetLineControlsA},
+{-1, 112, "mixerGetLineControlsW",        mixerGetLineControlsW},
+{-1, 113, "mixerGetLineInfoA",            mixerGetLineInfoA},
+{-1, 114, "mixerGetLineInfoW",            mixerGetLineInfoW},
+{-1, 115, "mixerGetNumDevs",              mixerGetNumDevs},
+{-1, 116, "mixerMessage",                 mixerMessage},
+{-1, 117, "mixerOpen",                    mixerOpen},
+{-1, 118, "mixerSetControlDetails",       mixerSetControlDetails},
+{-1, 119, "mmDrvInstall",                 mmDrvInstall},
+{-1, 120, "mmGetCurrentTask",             mmGetCurrentTask},
+{-1, 121, "mmTaskBlock",                  mmTaskBlock},
+{-1, 122, "mmTaskCreate",                 mmTaskCreate},
+{-1, 123, "mmTaskSignal",                 mmTaskSignal},
+{-1, 124, "mmTaskYield",                  mmTaskYield},
+{-1, 125, "mmioAdvance",                  mmioAdvance},
+{-1, 126, "mmioAscend",                   mmioAscend},
+{-1, 127, "mmioClose",                    mmioClose},
+{-1, 128, "mmioCreateChunk",              mmioCreateChunk},
+{-1, 129, "mmioDescend",                  mmioDescend},
+{-1, 130, "mmioFlush",                    mmioFlush},
+{-1, 131, "mmioGetInfo",                  mmioGetInfo},
+{-1, 132, "mmioInstallIOProcA",           mmioInstallIOProcA},
+{-1, 133, "mmioInstallIOProcW",           mmioInstallIOProcW},
+{-1, 134, "mmioOpenA",                    mmioOpenA},
+{-1, 135, "mmioOpenW",                    mmioOpenW},
+{-1, 136, "mmioRead",                     mmioRead},
+{-1, 137, "mmioRenameA",                  mmioRenameA},
+{-1, 138, "mmioRenameW",                  mmioRenameW},
+{-1, 139, "mmioSeek",                     mmioSeek},
+{-1, 140, "mmioSendMessage",              mmioSendMessage},
+{-1, 141, "mmioSetBuffer",                mmioSetBuffer},
+{-1, 142, "mmioSetInfo",                  mmioSetInfo},
+{-1, 143, "mmioStringToFOURCCA",          mmioStringToFOURCCA},
+{-1, 144, "mmioStringToFOURCCW",          mmioStringToFOURCCW},
+{-1, 145, "mmioWrite",                    mmioWrite},
+{-1, 146, "mmsystemGetVersion",           mmsystemGetVersion},
+{-1, 147, "mod32Message",                 mod32Message},
+{-1, 148, "mxd32Message",                 mxd32Message},
+{ 0, 149, "sndPlaySoundA",                sndPlaySoundA},
+{ 0, 150, "sndPlaySoundW",                sndPlaySoundW},
+{-1, 151, "tid32Message",                 tid32Message},
+{ 0, 152, "timeBeginPeriod",              timeBeginPeriod},
+{ 0, 153, "timeEndPeriod",                timeEndPeriod},
+{-1, 154, "timeGetDevCaps",               timeGetDevCaps},
+{-1, 155, "timeGetSystemTime",            timeGetSystemTime},
+{ 0, 156, "timeGetTime",                  timeGetTime},
+{-1, 157, "timeKillEvent",                timeKillEvent},
+{-1, 158, "timeSetEvent",                 timeSetEvent},
+{-1, 159, "waveInAddBuffer",              waveInAddBuffer},
+{-1, 160, "waveInClose",                  waveInClose},
+{-1, 161, "waveInGetDevCapsA",            waveInGetDevCapsA},
+{-1, 162, "waveInGetDevCapsW",            waveInGetDevCapsW},
+{-1, 163, "waveInGetErrorTextA",          waveInGetErrorTextA},
+{-1, 164, "waveInGetErrorTextW",          waveInGetErrorTextW},
+{-1, 165, "waveInGetID",                  waveInGetID},
+{-1, 166, "waveInGetNumDevs",             waveInGetNumDevs},
+{-1, 167, "waveInGetPosition",            waveInGetPosition},
+{-1, 168, "waveInMessage",                waveInMessage},
+{-1, 169, "waveInOpen",                   waveInOpen},
+{-1, 170, "waveInPrepareHeader",          waveInPrepareHeader},
+{-1, 171, "waveInReset",                  waveInReset},
+{-1, 172, "waveInStart",                  waveInStart},
+{-1, 173, "waveInStop",                   waveInStop},
+{-1, 174, "waveInUnprepareHeader",        waveInUnprepareHeader},
+{-1, 175, "waveOutBreakLoop",             waveOutBreakLoop},
+{-1, 176, "waveOutClose",                 waveOutClose},
+{-1, 177, "waveOutGetDevCapsA",           waveOutGetDevCapsA},
+{-1, 178, "waveOutGetDevCapsW",           waveOutGetDevCapsW},
+{-1, 179, "waveOutGetErrorTextA",         waveOutGetErrorTextA},
+{-1, 180, "waveOutGetErrorTextW",         waveOutGetErrorTextW},
+{-1, 181, "waveOutGetID",                 waveOutGetID},
+{-1, 182, "waveOutGetNumDevs",            waveOutGetNumDevs},
+{-1, 183, "waveOutGetPitch",              waveOutGetPitch},
+{-1, 184, "waveOutGetPlaybackRate",       waveOutGetPlaybackRate},
+{-1, 185, "waveOutGetPosition",           waveOutGetPosition},
+{-1, 186, "waveOutGetVolume",             waveOutGetVolume},
+{-1, 187, "waveOutMessage",               waveOutMessage},
+{-1, 188, "waveOutOpen",                  waveOutOpen},
+{-1, 189, "waveOutPause",                 waveOutPause},
+{-1, 190, "waveOutPrepareHeader",         waveOutPrepareHeader},
+{-1, 191, "waveOutReset",                 waveOutReset},
+{-1, 192, "waveOutRestart",               waveOutRestart},
+{-1, 193, "waveOutSetPitch",              waveOutSetPitch},
+{-1, 194, "waveOutSetPlaybackRate",       waveOutSetPlaybackRate},
+{-1, 195, "waveOutSetVolume",             waveOutSetVolume},
+{-1, 196, "waveOutUnprepareHeader",       waveOutUnprepareHeader},
+{-1, 197, "waveOutWrite",                 waveOutWrite},
+{-1, 198, "wid32Message",                 wid32Message},
+{-1, 199, "winmmDbgOut",                  winmmDbgOut},
+{-1, 200, "winmmSetDebugLevel",           winmmSetDebugLevel},
+{-1, 201, "wod32Message",                 wod32Message},
+{-1,   0, NULL,                           NULL}};
