@@ -1,10 +1,10 @@
 /*
     w32loader
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "winsock.h"
 #include "user32.h"
@@ -1075,80 +1074,80 @@ static int WINAPI winsock_socket (int domain, int type, int protocol)
 }
 
 
-W32LdrExport winsock_exports[] = {
-{FALSE, 1141, "AcceptEx",                    AcceptEx},
-{FALSE, 1111, "EnumProtocolsA",              EnumProtocolsA},
-{FALSE, 1112, "EnumProtocolsW",              EnumProtocolsW},
-{FALSE, 1142, "GetAcceptExSockaddrs",        GetAcceptExSockaddrs},
-{FALSE, 1109, "GetAddressByNameA",           GetAddressByNameA},
-{FALSE, 1110, "GetAddressByNameW",           GetAddressByNameW},
-{FALSE, 1115, "GetNameByTypeA",              GetNameByTypeA},
-{FALSE, 1116, "GetNameByTypeW",              GetNameByTypeW},
-{FALSE, 1119, "GetServiceA",                 GetServiceA},
-{FALSE, 1120, "GetServiceW",                 GetServiceW},
-{FALSE, 1113, "GetTypeByNameA",              GetTypeByNameA},
-{FALSE, 1114, "GetTypeByNameW",              GetTypeByNameW},
-{FALSE,   24, "MigrateWinsockConfiguration", MigrateWinsockConfiguration},
-{FALSE, 1130, "NPLoadNameSpaces",            NPLoadNameSpaces},
-{FALSE, 1117, "SetServiceA",                 SetServiceA},
-{FALSE, 1118, "SetServiceW",                 SetServiceW},
-{FALSE, 1140, "TransmitFile",                TransmitFile},
-{FALSE,  500, "WEP",                         WEP},
-{FALSE,  102, "WSAAsyncGetHostByAddr",       WSAAsyncGetHostByAddr},
-{TRUE,   103, "WSAAsyncGetHostByName",       WSAAsyncGetHostByName},
-{FALSE,  105, "WSAAsyncGetProtoByName",      WSAAsyncGetProtoByName},
-{FALSE,  104, "WSAAsyncGetProtoByNumber",    WSAAsyncGetProtoByNumber},
-{FALSE,  107, "WSAAsyncGetServByName",       WSAAsyncGetServByName},
-{FALSE,  106, "WSAAsyncGetServByPort",       WSAAsyncGetServByPort},
-{TRUE,   101, "WSAAsyncSelect",              WSAAsyncSelect},
-{TRUE,   108, "WSACancelAsyncRequest",       WSACancelAsyncRequest},
-{FALSE,  113, "WSACancelBlockingCall",       WSACancelBlockingCall},
-{TRUE,   116, "WSACleanup",                  WSACleanup},
-{TRUE,   111, "WSAGetLastError",             WSAGetLastError},
-{FALSE,  114, "WSAIsBlocking",               WSAIsBlocking},
-{FALSE, 1107, "WSARecvEx",                   WSARecvEx},
-{FALSE,  109, "WSASetBlockingHook",          WSASetBlockingHook},
-{FALSE,  112, "WSASetLastError",             WSASetLastError},
-{TRUE,   115, "WSAStartup",                  WSAStartup},
-{FALSE,  110, "WSAUnhookBlockingHook",       WSAUnhookBlockingHook},
-{FALSE, 1000, "WSApSetPostRoutine",          WSApSetPostRoutine},
-{FALSE,  151, "__WSAFDIsSet",                __WSAFDIsSet},
-{TRUE,     1, "accept",                      winsock_accept},
-{TRUE,     2, "bind",                        winsock_bind},
-{TRUE,     3, "closesocket",                 closesocket},
-{TRUE,     4, "connect",                     winsock_connect},
-{FALSE, 1106, "dn_expand",                   winsock_dn_expand},
-{TRUE,    51, "gethostbyaddr",               winsock_gethostbyaddr},
-{TRUE,    52, "gethostbyname",               winsock_gethostbyname},
-{TRUE,    57, "gethostname",                 winsock_gethostname},
-{TRUE,  1101, "getnetbyname",                winsock_getnetbyname},
-{TRUE,     5, "getpeername",                 winsock_getpeername},
-{TRUE,    53, "getprotobyname",              winsock_getprotobyname},
-{TRUE,    54, "getprotobynumber",            winsock_getprotobynumber},
-{TRUE,    55, "getservbyname",               winsock_getservbyname},
-{TRUE,    56, "getservbyport",               winsock_getservbyport},
-{TRUE,     6, "getsockname",                 winsock_getsockname},
-{TRUE,     7, "getsockopt",                  winsock_getsockopt},
-{TRUE,     8, "htonl",                       winsock_htonl},
-{TRUE,     9, "htons",                       winsock_htons},
-{TRUE,    10, "inet_addr",                   winsock_inet_addr},
-{TRUE,  1100, "inet_network",                winsock_inet_network},
-{TRUE,    11, "inet_ntoa",                   winsock_inet_ntoa},
-{FALSE,   12, "ioctlsocket",                 ioctlsocket},
-{TRUE,    13, "listen",                      winsock_listen},
-{TRUE,    14, "ntohl",                       winsock_ntohl},
-{TRUE,    15, "ntohs",                       winsock_ntohs},
-{FALSE, 1102, "rcmd",                        winsock_rcmd},
-{TRUE,    16, "recv",                        winsock_recv},
-{TRUE,    17, "recvfrom",                    winsock_recvfrom},
-{FALSE, 1103, "rexec",                       winsock_rexec},
-{FALSE, 1104, "rresvport",                   winsock_rresvport},
-{FALSE, 1108, "s_perror",                    s_perror},
-{TRUE,    18, "select",                      winsock_select},
-{TRUE,    19, "send",                        winsock_send},
-{TRUE,    20, "sendto",                      winsock_sendto},
-{TRUE,  1105, "sethostname",                 winsock_sethostname},
-{TRUE,    21, "setsockopt",                  winsock_setsockopt},
-{TRUE,    22, "shutdown",                    winsock_shutdown},
-{TRUE,    23, "socket",                      winsock_socket},
-{FALSE,    0, NULL,                          NULL}};
+W32LdrExport w32ldr_winsock_exports[] = {
+{-1, 1141, "AcceptEx",                    AcceptEx},
+{-1, 1111, "EnumProtocolsA",              EnumProtocolsA},
+{-1, 1112, "EnumProtocolsW",              EnumProtocolsW},
+{-1, 1142, "GetAcceptExSockaddrs",        GetAcceptExSockaddrs},
+{-1, 1109, "GetAddressByNameA",           GetAddressByNameA},
+{-1, 1110, "GetAddressByNameW",           GetAddressByNameW},
+{-1, 1115, "GetNameByTypeA",              GetNameByTypeA},
+{-1, 1116, "GetNameByTypeW",              GetNameByTypeW},
+{-1, 1119, "GetServiceA",                 GetServiceA},
+{-1, 1120, "GetServiceW",                 GetServiceW},
+{-1, 1113, "GetTypeByNameA",              GetTypeByNameA},
+{-1, 1114, "GetTypeByNameW",              GetTypeByNameW},
+{-1,   24, "MigrateWinsockConfiguration", MigrateWinsockConfiguration},
+{-1, 1130, "NPLoadNameSpaces",            NPLoadNameSpaces},
+{-1, 1117, "SetServiceA",                 SetServiceA},
+{-1, 1118, "SetServiceW",                 SetServiceW},
+{-1, 1140, "TransmitFile",                TransmitFile},
+{-1,  500, "WEP",                         WEP},
+{-1,  102, "WSAAsyncGetHostByAddr",       WSAAsyncGetHostByAddr},
+{ 0,  103, "WSAAsyncGetHostByName",       WSAAsyncGetHostByName},
+{-1,  105, "WSAAsyncGetProtoByName",      WSAAsyncGetProtoByName},
+{-1,  104, "WSAAsyncGetProtoByNumber",    WSAAsyncGetProtoByNumber},
+{-1,  107, "WSAAsyncGetServByName",       WSAAsyncGetServByName},
+{-1,  106, "WSAAsyncGetServByPort",       WSAAsyncGetServByPort},
+{ 0,  101, "WSAAsyncSelect",              WSAAsyncSelect},
+{ 0,  108, "WSACancelAsyncRequest",       WSACancelAsyncRequest},
+{-1,  113, "WSACancelBlockingCall",       WSACancelBlockingCall},
+{ 0,  116, "WSACleanup",                  WSACleanup},
+{ 0,  111, "WSAGetLastError",             WSAGetLastError},
+{-1,  114, "WSAIsBlocking",               WSAIsBlocking},
+{-1, 1107, "WSARecvEx",                   WSARecvEx},
+{-1,  109, "WSASetBlockingHook",          WSASetBlockingHook},
+{-1,  112, "WSASetLastError",             WSASetLastError},
+{ 0,  115, "WSAStartup",                  WSAStartup},
+{-1,  110, "WSAUnhookBlockingHook",       WSAUnhookBlockingHook},
+{-1, 1000, "WSApSetPostRoutine",          WSApSetPostRoutine},
+{-1,  151, "__WSAFDIsSet",                __WSAFDIsSet},
+{ 0,    1, "accept",                      winsock_accept},
+{ 0,    2, "bind",                        winsock_bind},
+{ 0,    3, "closesocket",                 closesocket},
+{ 0,    4, "connect",                     winsock_connect},
+{-1, 1106, "dn_expand",                   winsock_dn_expand},
+{ 0,   51, "gethostbyaddr",               winsock_gethostbyaddr},
+{ 0,   52, "gethostbyname",               winsock_gethostbyname},
+{ 0,   57, "gethostname",                 winsock_gethostname},
+{ 0, 1101, "getnetbyname",                winsock_getnetbyname},
+{ 0,    5, "getpeername",                 winsock_getpeername},
+{ 0,   53, "getprotobyname",              winsock_getprotobyname},
+{ 0,   54, "getprotobynumber",            winsock_getprotobynumber},
+{ 0,   55, "getservbyname",               winsock_getservbyname},
+{ 0,   56, "getservbyport",               winsock_getservbyport},
+{ 0,    6, "getsockname",                 winsock_getsockname},
+{ 0,    7, "getsockopt",                  winsock_getsockopt},
+{ 0,    8, "htonl",                       winsock_htonl},
+{ 0,    9, "htons",                       winsock_htons},
+{ 0,   10, "inet_addr",                   winsock_inet_addr},
+{ 0, 1100, "inet_network",                winsock_inet_network},
+{ 0,   11, "inet_ntoa",                   winsock_inet_ntoa},
+{-1,   12, "ioctlsocket",                 ioctlsocket},
+{ 0,   13, "listen",                      winsock_listen},
+{ 0,   14, "ntohl",                       winsock_ntohl},
+{ 0,   15, "ntohs",                       winsock_ntohs},
+{-1, 1102, "rcmd",                        winsock_rcmd},
+{ 0,   16, "recv",                        winsock_recv},
+{ 0,   17, "recvfrom",                    winsock_recvfrom},
+{-1, 1103, "rexec",                       winsock_rexec},
+{-1, 1104, "rresvport",                   winsock_rresvport},
+{-1, 1108, "s_perror",                    s_perror},
+{ 0,   18, "select",                      winsock_select},
+{ 0,   19, "send",                        winsock_send},
+{ 0,   20, "sendto",                      winsock_sendto},
+{ 0, 1105, "sethostname",                 winsock_sethostname},
+{ 0,   21, "setsockopt",                  winsock_setsockopt},
+{ 0,   22, "shutdown",                    winsock_shutdown},
+{ 0,   23, "socket",                      winsock_socket},
+{-1,    0, NULL,                          NULL}};
